pub enum AffiliateProgramSortOrder {
Profitability,
CreationDate,
Revenue,
}Variants
Profitability
The affiliate programs must be sorted by the profitability
CreationDate
The affiliate programs must be sorted by creation date
Revenue
The affiliate programs must be sorted by the expected revenue