pub enum AffiliateType {
CurrentUser,
Bot(AffiliateTypeBot),
Channel(AffiliateTypeChannel),
}Variants
CurrentUser
The affiliate is the current user
Bot(AffiliateTypeBot)
The affiliate is a bot owned by the current user
Channel(AffiliateTypeChannel)
The affiliate is a channel chat where the current user has can_post_messages administrator right