pub enum AttributeCraftPersistenceProbability {
AttributeCraftPersistenceProbability(AttributeCraftPersistenceProbability),
}Variants
AttributeCraftPersistenceProbability(AttributeCraftPersistenceProbability)
Describes chance of the crafted gift to have the backdrop or symbol of one of the original gifts