pub enum BotMediaPreviewInfo {
BotMediaPreviewInfo(BotMediaPreviewInfo),
}Variants
BotMediaPreviewInfo(BotMediaPreviewInfo)
Contains a list of media previews of a bot for the given language and the list of languages for which the bot has dedicated previews