pub enum ChatInviteLinkSubscriptionInfo {
ChatInviteLinkSubscriptionInfo(ChatInviteLinkSubscriptionInfo),
}Variants
ChatInviteLinkSubscriptionInfo(ChatInviteLinkSubscriptionInfo)
Contains information about subscription plan that must be paid by the user to use a chat invite link