pub enum FileType {
Show 23 variants
None,
Animation,
Audio,
Document,
NotificationSound,
Photo,
PhotoStory,
ProfilePhoto,
Secret,
SecretThumbnail,
Secure,
SelfDestructingPhoto,
SelfDestructingVideo,
SelfDestructingVideoNote,
SelfDestructingVoiceNote,
Sticker,
Thumbnail,
Unknown,
Video,
VideoNote,
VideoStory,
VoiceNote,
Wallpaper,
}Variants
None
The data is not a file
Animation
The file is an animation
Audio
The file is an audio file
Document
The file is a document
NotificationSound
The file is a notification sound
Photo
The file is a photo
PhotoStory
The file is a photo published as a story
ProfilePhoto
The file is a profile photo
Secret
The file was sent to a secret chat (the file type is not known to the server)
SecretThumbnail
The file is a thumbnail of a file from a secret chat
Secure
The file is a file from Secure storage used for storing Telegram Passport files
SelfDestructingPhoto
The file is a self-destructing photo in a private chat
SelfDestructingVideo
The file is a self-destructing video in a private chat
SelfDestructingVideoNote
The file is a self-destructing video note in a private chat
SelfDestructingVoiceNote
The file is a self-destructing voice note in a private chat
Sticker
The file is a sticker
Thumbnail
The file is a thumbnail of another file
Unknown
The file type is not yet known
Video
The file is a video
VideoNote
The file is a video note
VideoStory
The file is a video published as a story
VoiceNote
The file is a voice note
Wallpaper
The file is a wallpaper or a background pattern