pub enum InviteGroupCallParticipantResult {
UserPrivacyRestricted,
UserAlreadyParticipant,
UserWasBanned,
Success(InviteGroupCallParticipantResultSuccess),
}Variants
UserPrivacyRestricted
The user can’t be invited due to their privacy settings
UserAlreadyParticipant
The user can’t be invited because they are already a participant of the call
UserWasBanned
The user can’t be invited because they were banned by the owner of the call and can be invited back only by the owner of the group call
Success(InviteGroupCallParticipantResultSuccess)
The user was invited and a service message of the type messageGroupCall was sent which can be used in declineGroupCallInvitation to cancel the invitation