LinkPreviewType

Enum LinkPreviewType 

pub enum LinkPreviewType {
Show 38 variants Album(LinkPreviewTypeAlbum), Animation(LinkPreviewTypeAnimation), App(LinkPreviewTypeApp), Article(LinkPreviewTypeArticle), Audio(LinkPreviewTypeAudio), Background(LinkPreviewTypeBackground), ChannelBoost(LinkPreviewTypeChannelBoost), Chat(LinkPreviewTypeChat), DirectMessagesChat(LinkPreviewTypeDirectMessagesChat), Document(LinkPreviewTypeDocument), EmbeddedAnimationPlayer(LinkPreviewTypeEmbeddedAnimationPlayer), EmbeddedAudioPlayer(LinkPreviewTypeEmbeddedAudioPlayer), EmbeddedVideoPlayer(LinkPreviewTypeEmbeddedVideoPlayer), ExternalAudio(LinkPreviewTypeExternalAudio), ExternalVideo(LinkPreviewTypeExternalVideo), GiftAuction(LinkPreviewTypeGiftAuction), GiftCollection(LinkPreviewTypeGiftCollection), GroupCall, Invoice, LiveStory(LinkPreviewTypeLiveStory), Message, Photo(LinkPreviewTypePhoto), PremiumGiftCode, ShareableChatFolder, Sticker(LinkPreviewTypeSticker), StickerSet(LinkPreviewTypeStickerSet), Story(LinkPreviewTypeStory), StoryAlbum(LinkPreviewTypeStoryAlbum), SupergroupBoost(LinkPreviewTypeSupergroupBoost), Theme(LinkPreviewTypeTheme), Unsupported, UpgradedGift(LinkPreviewTypeUpgradedGift), User(LinkPreviewTypeUser), Video(LinkPreviewTypeVideo), VideoChat(LinkPreviewTypeVideoChat), VideoNote(LinkPreviewTypeVideoNote), VoiceNote(LinkPreviewTypeVoiceNote), WebApp(LinkPreviewTypeWebApp),
}

Variants



Album(LinkPreviewTypeAlbum)

The link is a link to a media album consisting of photos and videos



Animation(LinkPreviewTypeAnimation)

The link is a link to an animation



App(LinkPreviewTypeApp)

The link is a link to an app at App Store or Google Play



Article(LinkPreviewTypeArticle)

The link is a link to a web site



Audio(LinkPreviewTypeAudio)

The link is a link to an audio



Background(LinkPreviewTypeBackground)

The link is a link to a background. Link preview title and description are available only for filled backgrounds



ChannelBoost(LinkPreviewTypeChannelBoost)

The link is a link to boost a channel chat



Chat(LinkPreviewTypeChat)

The link is a link to a chat



DirectMessagesChat(LinkPreviewTypeDirectMessagesChat)

The link is a link to a direct messages chat of a channel



Document(LinkPreviewTypeDocument)

The link is a link to a general file



EmbeddedAnimationPlayer(LinkPreviewTypeEmbeddedAnimationPlayer)

The link is a link to an animation player



EmbeddedAudioPlayer(LinkPreviewTypeEmbeddedAudioPlayer)

The link is a link to an audio player



EmbeddedVideoPlayer(LinkPreviewTypeEmbeddedVideoPlayer)

The link is a link to a video player



ExternalAudio(LinkPreviewTypeExternalAudio)

The link is a link to an audio file



ExternalVideo(LinkPreviewTypeExternalVideo)

The link is a link to a video file



GiftAuction(LinkPreviewTypeGiftAuction)

The link is a link to a gift auction



GiftCollection(LinkPreviewTypeGiftCollection)

The link is a link to a gift collection



GroupCall

The link is a link to a group call that isn’t bound to a chat



Invoice

The link is a link to an invoice



LiveStory(LinkPreviewTypeLiveStory)

The link is a link to a live story group call



Message

The link is a link to a text or a poll Telegram message



Photo(LinkPreviewTypePhoto)

The link is a link to a photo



PremiumGiftCode

The link is a link to a Telegram Premium gift code



ShareableChatFolder

The link is a link to a shareable chat folder



Sticker(LinkPreviewTypeSticker)

The link is a link to a sticker



StickerSet(LinkPreviewTypeStickerSet)

The link is a link to a sticker set



Story(LinkPreviewTypeStory)

The link is a link to a story. Link preview description is unavailable



StoryAlbum(LinkPreviewTypeStoryAlbum)

The link is a link to an album of stories



SupergroupBoost(LinkPreviewTypeSupergroupBoost)

The link is a link to boost a supergroup chat



Theme(LinkPreviewTypeTheme)

The link is a link to a cloud theme. TDLib has no theme support yet



Unsupported

The link preview type is unsupported yet



UpgradedGift(LinkPreviewTypeUpgradedGift)

The link is a link to an upgraded gift



User(LinkPreviewTypeUser)

The link is a link to a user



Video(LinkPreviewTypeVideo)

The link is a link to a video



VideoChat(LinkPreviewTypeVideoChat)

The link is a link to a video chat



VideoNote(LinkPreviewTypeVideoNote)

The link is a link to a video note message



VoiceNote(LinkPreviewTypeVoiceNote)

The link is a link to a voice note message



WebApp(LinkPreviewTypeWebApp)

The link is a link to a Web App