pub enum MessageProperties {
MessageProperties(MessageProperties),
}Variants
MessageProperties(MessageProperties)
Contains properties of a message and describes actions that can be done with the message right now