pub enum PaidReactionType {
Regular,
Anonymous,
Chat(PaidReactionTypeChat),
}Variants
Regular
A paid reaction on behalf of the current user
Anonymous
An anonymous paid reaction
Chat(PaidReactionTypeChat)
A paid reaction on behalf of an owned chat