pub enum PaymentFormType {
Regular(PaymentFormTypeRegular),
Stars(PaymentFormTypeStars),
StarSubscription(PaymentFormTypeStarSubscription),
}Variants
Regular(PaymentFormTypeRegular)
The payment form is for a regular payment
Stars(PaymentFormTypeStars)
The payment form is for a payment in Telegram Stars
StarSubscription(PaymentFormTypeStarSubscription)
The payment form is for a payment in Telegram Stars for subscription