pub enum ProfileTab {
Posts,
Gifts,
Media,
Files,
Links,
Music,
Voice,
Gifs,
}Variants
Posts
A tab with stories posted by the user or the channel chat and saved to profile
Gifts
A tab with gifts received by the user or the channel chat
Media
A tab with photos and videos posted by the channel
Files
A tab with documents posted by the channel
Links
A tab with messages posted by the channel and containing links
Music
A tab with audio messages posted by the channel
Voice
A tab with voice notes posted by the channel
Gifs
A tab with animations posted by the channel