pub enum ReportChatResult {
Ok,
OptionRequired(ReportChatResultOptionRequired),
TextRequired(ReportChatResultTextRequired),
MessagesRequired,
}Variants
Ok
The chat was reported successfully
OptionRequired(ReportChatResultOptionRequired)
The user must choose an option to report the chat and repeat request with the chosen option
TextRequired(ReportChatResultTextRequired)
The user must add additional text details to the report
MessagesRequired
The user must choose messages to report and repeat the reportChat request with the chosen messages