pub enum StarSubscription {
StarSubscription(StarSubscription),
}Variants
StarSubscription(StarSubscription)
Contains information about subscription to a channel chat, a bot, or a business account that was paid in Telegram Stars