StarTransactionType

Enum StarTransactionType 

pub enum StarTransactionType {
Show 45 variants PremiumBotDeposit, AppStoreDeposit, GooglePlayDeposit, FragmentDeposit, UserDeposit(StarTransactionTypeUserDeposit), GiveawayDeposit(StarTransactionTypeGiveawayDeposit), FragmentWithdrawal(StarTransactionTypeFragmentWithdrawal), TelegramAdsWithdrawal, TelegramApiUsage(StarTransactionTypeTelegramApiUsage), BotPaidMediaPurchase(StarTransactionTypeBotPaidMediaPurchase), BotPaidMediaSale(StarTransactionTypeBotPaidMediaSale), ChannelPaidMediaPurchase(StarTransactionTypeChannelPaidMediaPurchase), ChannelPaidMediaSale(StarTransactionTypeChannelPaidMediaSale), BotInvoicePurchase(StarTransactionTypeBotInvoicePurchase), BotInvoiceSale(StarTransactionTypeBotInvoiceSale), BotSubscriptionPurchase(StarTransactionTypeBotSubscriptionPurchase), BotSubscriptionSale(StarTransactionTypeBotSubscriptionSale), ChannelSubscriptionPurchase(StarTransactionTypeChannelSubscriptionPurchase), ChannelSubscriptionSale(StarTransactionTypeChannelSubscriptionSale), GiftAuctionBid(StarTransactionTypeGiftAuctionBid), GiftPurchase(StarTransactionTypeGiftPurchase), GiftPurchaseOffer(StarTransactionTypeGiftPurchaseOffer), GiftTransfer(StarTransactionTypeGiftTransfer), GiftOriginalDetailsDrop(StarTransactionTypeGiftOriginalDetailsDrop), GiftSale(StarTransactionTypeGiftSale), GiftUpgrade(StarTransactionTypeGiftUpgrade), GiftUpgradePurchase(StarTransactionTypeGiftUpgradePurchase), UpgradedGiftPurchase(StarTransactionTypeUpgradedGiftPurchase), UpgradedGiftSale(StarTransactionTypeUpgradedGiftSale), ChannelPaidReactionSend(StarTransactionTypeChannelPaidReactionSend), ChannelPaidReactionReceive(StarTransactionTypeChannelPaidReactionReceive), AffiliateProgramCommission(StarTransactionTypeAffiliateProgramCommission), PaidMessageSend(StarTransactionTypePaidMessageSend), PaidMessageReceive(StarTransactionTypePaidMessageReceive), PaidGroupCallMessageSend(StarTransactionTypePaidGroupCallMessageSend), PaidGroupCallMessageReceive(StarTransactionTypePaidGroupCallMessageReceive), PaidGroupCallReactionSend(StarTransactionTypePaidGroupCallReactionSend), PaidGroupCallReactionReceive(StarTransactionTypePaidGroupCallReactionReceive), SuggestedPostPaymentSend(StarTransactionTypeSuggestedPostPaymentSend), SuggestedPostPaymentReceive(StarTransactionTypeSuggestedPostPaymentReceive), PremiumPurchase(StarTransactionTypePremiumPurchase), BusinessBotTransferSend(StarTransactionTypeBusinessBotTransferSend), BusinessBotTransferReceive(StarTransactionTypeBusinessBotTransferReceive), PublicPostSearch, Unsupported,
}

Variants



PremiumBotDeposit

The transaction is a deposit of Telegram Stars from the Premium bot; relevant for regular users only



AppStoreDeposit

The transaction is a deposit of Telegram Stars from App Store; relevant for regular users only



GooglePlayDeposit

The transaction is a deposit of Telegram Stars from Google Play; relevant for regular users only



FragmentDeposit

The transaction is a deposit of Telegram Stars from Fragment; relevant for regular users and bots only



UserDeposit(StarTransactionTypeUserDeposit)

The transaction is a deposit of Telegram Stars by another user; relevant for regular users only



GiveawayDeposit(StarTransactionTypeGiveawayDeposit)

The transaction is a deposit of Telegram Stars from a giveaway; relevant for regular users only



FragmentWithdrawal(StarTransactionTypeFragmentWithdrawal)

The transaction is a withdrawal of earned Telegram Stars to Fragment; relevant for regular users, bots, supergroup and channel chats only



TelegramAdsWithdrawal

The transaction is a withdrawal of earned Telegram Stars to Telegram Ad platform; relevant for bots and channel chats only



TelegramApiUsage(StarTransactionTypeTelegramApiUsage)

The transaction is a payment for Telegram API usage; relevant for bots only



BotPaidMediaPurchase(StarTransactionTypeBotPaidMediaPurchase)

The transaction is a purchase of paid media from a bot or a business account by the current user; relevant for regular users only



BotPaidMediaSale(StarTransactionTypeBotPaidMediaSale)

The transaction is a sale of paid media by the bot or a business account managed by the bot; relevant for bots only



ChannelPaidMediaPurchase(StarTransactionTypeChannelPaidMediaPurchase)

The transaction is a purchase of paid media from a channel by the current user; relevant for regular users only



ChannelPaidMediaSale(StarTransactionTypeChannelPaidMediaSale)

The transaction is a sale of paid media by the channel chat; relevant for channel chats only



BotInvoicePurchase(StarTransactionTypeBotInvoicePurchase)

The transaction is a purchase of a product from a bot or a business account by the current user; relevant for regular users only



BotInvoiceSale(StarTransactionTypeBotInvoiceSale)

The transaction is a sale of a product by the bot; relevant for bots only



BotSubscriptionPurchase(StarTransactionTypeBotSubscriptionPurchase)

The transaction is a purchase of a subscription from a bot or a business account by the current user; relevant for regular users only



BotSubscriptionSale(StarTransactionTypeBotSubscriptionSale)

The transaction is a sale of a subscription by the bot; relevant for bots only



ChannelSubscriptionPurchase(StarTransactionTypeChannelSubscriptionPurchase)

The transaction is a purchase of a subscription to a channel chat by the current user; relevant for regular users only



ChannelSubscriptionSale(StarTransactionTypeChannelSubscriptionSale)

The transaction is a sale of a subscription by the channel chat; relevant for channel chats only



GiftAuctionBid(StarTransactionTypeGiftAuctionBid)

The transaction is a bid on a gift auction; relevant for regular users only



GiftPurchase(StarTransactionTypeGiftPurchase)

The transaction is a purchase of a regular gift; relevant for regular users and bots only



GiftPurchaseOffer(StarTransactionTypeGiftPurchaseOffer)

The transaction is an offer of gift purchase; relevant for regular users only



GiftTransfer(StarTransactionTypeGiftTransfer)

The transaction is a transfer of an upgraded gift; relevant for regular users only



GiftOriginalDetailsDrop(StarTransactionTypeGiftOriginalDetailsDrop)

The transaction is a drop of original details of an upgraded gift; relevant for regular users only



GiftSale(StarTransactionTypeGiftSale)

The transaction is a sale of a received gift; relevant for regular users and channel chats only



GiftUpgrade(StarTransactionTypeGiftUpgrade)

The transaction is an upgrade of a gift; relevant for regular users only



GiftUpgradePurchase(StarTransactionTypeGiftUpgradePurchase)

The transaction is a purchase of an upgrade of a gift owned by another user or channel; relevant for regular users only



UpgradedGiftPurchase(StarTransactionTypeUpgradedGiftPurchase)

The transaction is a purchase of an upgraded gift for some user or channel; relevant for regular users only



UpgradedGiftSale(StarTransactionTypeUpgradedGiftSale)

The transaction is a sale of an upgraded gift; relevant for regular users only



ChannelPaidReactionSend(StarTransactionTypeChannelPaidReactionSend)

The transaction is a sending of a paid reaction to a message in a channel chat by the current user; relevant for regular users only



ChannelPaidReactionReceive(StarTransactionTypeChannelPaidReactionReceive)

The transaction is a receiving of a paid reaction to a message by the channel chat; relevant for channel chats only



AffiliateProgramCommission(StarTransactionTypeAffiliateProgramCommission)

The transaction is a receiving of a commission from an affiliate program; relevant for regular users, bots and channel chats only



PaidMessageSend(StarTransactionTypePaidMessageSend)

The transaction is a sending of a paid message; relevant for regular users only



PaidMessageReceive(StarTransactionTypePaidMessageReceive)

The transaction is a receiving of a paid message; relevant for regular users, supergroup and channel chats only



PaidGroupCallMessageSend(StarTransactionTypePaidGroupCallMessageSend)

The transaction is a sending of a paid group call message; relevant for regular users only



PaidGroupCallMessageReceive(StarTransactionTypePaidGroupCallMessageReceive)

The transaction is a receiving of a paid group call message; relevant for regular users and channel chats only



PaidGroupCallReactionSend(StarTransactionTypePaidGroupCallReactionSend)

The transaction is a sending of a paid group reaction; relevant for regular users only



PaidGroupCallReactionReceive(StarTransactionTypePaidGroupCallReactionReceive)

The transaction is a receiving of a paid group call reaction; relevant for regular users and channel chats only



SuggestedPostPaymentSend(StarTransactionTypeSuggestedPostPaymentSend)

The transaction is a payment for a suggested post; relevant for regular users only



SuggestedPostPaymentReceive(StarTransactionTypeSuggestedPostPaymentReceive)

The transaction is a receiving of a payment for a suggested post by the channel chat; relevant for channel chats only



PremiumPurchase(StarTransactionTypePremiumPurchase)

The transaction is a purchase of Telegram Premium subscription; relevant for regular users and bots only



BusinessBotTransferSend(StarTransactionTypeBusinessBotTransferSend)

The transaction is a transfer of Telegram Stars to a business bot; relevant for regular users only



BusinessBotTransferReceive(StarTransactionTypeBusinessBotTransferReceive)

The transaction is a transfer of Telegram Stars from a business account; relevant for bots only



PublicPostSearch

The transaction is a payment for search of posts in public Telegram channels; relevant for regular users only



Unsupported

The transaction is a transaction of an unsupported type