pub enum TonTransactionType {
FragmentDeposit(TonTransactionTypeFragmentDeposit),
FragmentWithdrawal(TonTransactionTypeFragmentWithdrawal),
SuggestedPostPayment(TonTransactionTypeSuggestedPostPayment),
GiftPurchaseOffer(TonTransactionTypeGiftPurchaseOffer),
UpgradedGiftPurchase(TonTransactionTypeUpgradedGiftPurchase),
UpgradedGiftSale(TonTransactionTypeUpgradedGiftSale),
StakeDiceStake,
StakeDicePayout,
Unsupported,
}Variants
FragmentDeposit(TonTransactionTypeFragmentDeposit)
The transaction is a deposit of Toncoins from Fragment
FragmentWithdrawal(TonTransactionTypeFragmentWithdrawal)
The transaction is a withdrawal of earned Toncoins to Fragment
SuggestedPostPayment(TonTransactionTypeSuggestedPostPayment)
The transaction is a payment for a suggested post
GiftPurchaseOffer(TonTransactionTypeGiftPurchaseOffer)
The transaction is an offer of gift purchase
UpgradedGiftPurchase(TonTransactionTypeUpgradedGiftPurchase)
The transaction is a purchase of an upgraded gift for some user or channel
UpgradedGiftSale(TonTransactionTypeUpgradedGiftSale)
The transaction is a sale of an upgraded gift
StakeDiceStake
The transaction is a payment for stake dice throw
StakeDicePayout
The transaction is a payment for successful stake dice throw
Unsupported
The transaction is a transaction of an unsupported type