pub enum UpgradedGiftOrigin {
Upgrade(UpgradedGiftOriginUpgrade),
Transfer,
Resale(UpgradedGiftOriginResale),
Blockchain,
PrepaidUpgrade,
Offer(UpgradedGiftOriginOffer),
Craft,
}Variants
Upgrade(UpgradedGiftOriginUpgrade)
The gift was obtained by upgrading of a previously received gift
Transfer
The gift was transferred from another owner
Resale(UpgradedGiftOriginResale)
The gift was bought from another user
Blockchain
The gift was assigned from blockchain and isn’t owned by the current user. The gift can’t be transferred, resold or withdrawn to blockchain
PrepaidUpgrade
The sender or receiver of the message has paid for upgraid of the gift, which has been completed
Offer(UpgradedGiftOriginOffer)
The gift was bought through an offer
Craft
The gift was crafted from other gifts