connect_affiliate_program

Function connect_affiliate_program 

pub async fn connect_affiliate_program(
    affiliate: AffiliateType,
    bot_user_id: i64,
    client_id: i32,
) -> Result<ConnectedAffiliateProgram, Error>
Connects an affiliate program to the given affiliate. Returns information about the connected affiliate program

Arguments

  • affiliate - The affiliate to which the affiliate program will be connected
  • bot_user_id - Identifier of the bot, which affiliate program is connected
  • client_id - The client id to send the request to