pub async fn edit_inline_message_caption(
inline_message_id: String,
reply_markup: Option<ReplyMarkup>,
caption: Option<FormattedText>,
show_caption_above_media: bool,
client_id: i32,
) -> Result<(), Error>Expand description
Edits the caption of an inline message sent via a bot; for bots only
Arguments
inline_message_id- Inline message identifierreply_markup- The new message reply markup; pass null if nonecaption- New message content caption; pass null to remove caption; 0-getOption(“message_caption_length_max”) charactersshow_caption_above_media- Pass true to show the caption above the media; otherwise, the caption will be shown below the media. May be true only for animation, photo, and video messagesclient_id- The client id to send the request to