edit_message_checklist

Function edit_message_checklist 

pub async fn edit_message_checklist(
    chat_id: i64,
    message_id: i64,
    reply_markup: Option<ReplyMarkup>,
    checklist: InputChecklist,
    client_id: i32,
) -> Result<Message, Error>
Edits the message content of a checklist. Returns the edited message after the edit is completed on the server side

Arguments

  • chat_id - The chat the message belongs to
  • message_id - Identifier of the message. Use messageProperties.can_be_edited to check whether the message can be edited
  • reply_markup - The new message reply markup; pass null if none; for bots only
  • checklist - The new checklist. If some tasks were completed, this information will be kept
  • client_id - The client id to send the request to