get_connected_affiliate_program

Function get_connected_affiliate_program 

pub async fn get_connected_affiliate_program(
    affiliate: AffiliateType,
    bot_user_id: i64,
    client_id: i32,
) -> Result<ConnectedAffiliateProgram, Error>
Returns an affiliate program that was connected to the given affiliate by identifier of the bot that created the program

Arguments

  • affiliate - The affiliate to which the affiliate program will be connected
  • bot_user_id - Identifier of the bot that created the program
  • client_id - The client id to send the request to