register_device

Function register_device 

pub async fn register_device(
    device_token: DeviceToken,
    other_user_ids: Vec<i64>,
    client_id: i32,
) -> Result<PushReceiverId, Error>
Registers the currently used device for receiving push notifications. Returns a globally unique identifier of the push notification subscription

Arguments

  • device_token - Device token
  • other_user_ids - List of user identifiers of other users currently using the application
  • client_id - The client id to send the request to