save_prepared_inline_message

Function save_prepared_inline_message 

pub async fn save_prepared_inline_message(
    user_id: i64,
    result: InputInlineQueryResult,
    chat_types: TargetChatTypes,
    client_id: i32,
) -> Result<PreparedInlineMessageId, Error>
Saves an inline message to be sent by the given user; for bots only

Arguments

  • user_id - Identifier of the user
  • result - The description of the message
  • chat_types - Types of the chats to which the message can be sent
  • client_id - The client id to send the request to