send_text_message_draft

Function send_text_message_draft 

pub async fn send_text_message_draft(
    chat_id: i64,
    forum_topic_id: i32,
    draft_id: i64,
    text: FormattedText,
    client_id: i32,
) -> Result<(), Error>
Sends a draft for a being generated text message; for bots only

Arguments

  • chat_id - Chat identifier
  • forum_topic_id - The forum topic identifier in which the message will be sent; pass 0 if none
  • draft_id - Unique identifier of the draft
  • text - Draft text of the message
  • client_id - The client id to send the request to