set_chat_affiliate_program

Function set_chat_affiliate_program 

pub async fn set_chat_affiliate_program(
    chat_id: i64,
    parameters: Option<AffiliateProgramParameters>,
    client_id: i32,
) -> Result<(), Error>
Changes affiliate program for a bot

Arguments

  • chat_id - Identifier of the chat with an owned bot for which affiliate program is changed
  • parameters - Parameters of the affiliate program; pass null to close the currently active program. If there is an active program, then commission and program duration can only be increased. If the active program is scheduled to be closed, then it can’t be changed anymore
  • client_id - The client id to send the request to