pub async fn test_proxy(
proxy: Proxy,
dc_id: i32,
timeout: f64,
client_id: i32,
) -> Result<(), Error>Expand description
Sends a simple network request to the Telegram servers via proxy; for testing only. Can be called before authorization
Arguments
proxy- The proxy to testdc_id- Identifier of a datacenter with which to test connectiontimeout- The maximum overall timeout for the requestclient_id- The client id to send the request to