pub struct AcceptedGiftTypes {
pub unlimited_gifts: bool,
pub limited_gifts: bool,
pub upgraded_gifts: bool,
pub gifts_from_channels: bool,
pub premium_subscription: bool,
}Expand description
Describes gift types that are accepted by a user
Fields
unlimited_gifts: boolTrue, if unlimited regular gifts are accepted
limited_gifts: boolTrue, if limited regular gifts are accepted
upgraded_gifts: boolTrue, if upgraded gifts and regular gifts that can be upgraded for free are accepted
gifts_from_channels: boolTrue, if gifts from channels are accepted subject to other restrictions
True, if Telegram Premium subscription is accepted