pub struct AccountInfo {
pub registration_month: i32,
pub registration_year: i32,
pub phone_number_country_code: String,
pub last_name_change_date: i32,
pub last_photo_change_date: i32,
}Expand description
Contains basic information about another user who started a chat with the current user
Fields
registration_month: i32Month when the user was registered in Telegram; 0-12; may be 0 if unknown
registration_year: i32Year when the user was registered in Telegram; 0-9999; may be 0 if unknown
phone_number_country_code: StringA two-letter ISO 3166-1 alpha-2 country code based on the phone number of the user; may be empty if unknown
last_name_change_date: i32Point in time (Unix timestamp) when the user changed name last time; 0 if unknown
last_photo_change_date: i32Point in time (Unix timestamp) when the user changed photo last time; 0 if unknown