pub struct AdvertisementSponsor {
pub url: String,
pub photo: Option<Photo>,
pub info: String,
}Expand description
Information about the sponsor of an advertisement
Fields
url: StringURL of the sponsor to be opened when the advertisement is clicked
photo: Option<Photo>Photo of the sponsor; may be null if must not be shown
info: StringAdditional optional information about the sponsor to be shown along with the advertisement