pub struct AffiliateInfo {
pub commission_per_mille: i32,
pub affiliate_chat_id: i64,
pub star_amount: StarAmount,
}Expand description
Contains information about an affiliate that received commission from a Telegram Star transaction
Fields
commission_per_mille: i32The number of Telegram Stars received by the affiliate for each 1000 Telegram Stars received by the program owner
affiliate_chat_id: i64Identifier of the chat which received the commission
star_amount: StarAmountThe Telegram Star amount that was received by the affiliate; can be negative for refunds