AgeVerificationParameters

Struct AgeVerificationParameters 

pub struct AgeVerificationParameters {
    pub min_age: i32,
    pub verification_bot_username: String,
    pub country: String,
}
Describes parameters for age verification of the current user

Fields

min_age: i32

The minimum age required to view restricted content

verification_bot_username: String

Username of the bot which main Web App may be used to verify age of the user

country: String

Unique name for the country or region, which legislation required age verification. May be used to get the corresponding localization key