pub struct AuctionBid {
pub star_count: i64,
pub bid_date: i32,
pub position: i32,
}Expand description
Describes a bid in an auction
Fields
star_count: i64The number of Telegram Stars that were put in the bid
bid_date: i32Point in time (Unix timestamp) when the bid was made
position: i32Position of the bid in the list of all bids