pub struct AuctionRound {
pub number: i32,
pub duration: i32,
pub extend_time: i32,
pub top_winner_count: i32,
}Expand description
Describes a round of an auction
Fields
number: i321-based number of the round
duration: i32Duration of the round, in seconds
extend_time: i32The number of seconds for which the round will be extended if there are changes in the top winners
top_winner_count: i32The number of top winners who trigger round extension if changed