pub struct AuctionStateFinished {
pub start_date: i32,
pub end_date: i32,
pub average_price: i64,
pub acquired_item_count: i32,
pub telegram_listed_item_count: i32,
pub fragment_listed_item_count: i32,
pub fragment_url: String,
}Expand description
Contains information about a finished auction
Fields
start_date: i32Point in time (Unix timestamp) when the auction started
end_date: i32Point in time (Unix timestamp) when the auction will be ended
average_price: i64Average price of bought items in Telegram Stars
acquired_item_count: i32The number of items that were purchased by the current user on the auction
telegram_listed_item_count: i32Number of items from the auction being resold on Telegram
fragment_listed_item_count: i32Number of items from the auction being resold on Fragment
fragment_url: StringThe HTTPS link to the Fragment for the resold items; may be empty if there are no such items being sold on Fragment