pub struct AuthorizationStateWaitPremiumPurchase {
pub store_product_id: String,
pub support_email_address: String,
pub support_email_subject: String,
}Expand description
The user must buy Telegram Premium as an in-store purchase to log in. Call checkAuthenticationPremiumPurchase and then setAuthenticationPremiumPurchaseTransaction
Fields
store_product_id: StringIdentifier of the store product that must be bought
support_email_address: StringEmail address to use for support if the user has issues with Telegram Premium purchase
support_email_subject: StringSubject for the email sent to the support email address