BotInfo

Struct BotInfo 

pub struct BotInfo {
Show 22 fields pub short_description: String, pub description: String, pub photo: Option<Photo>, pub animation: Option<Animation>, pub menu_button: Option<BotMenuButton>, pub commands: Vec<BotCommand>, pub privacy_policy_url: String, pub default_group_administrator_rights: Option<ChatAdministratorRights>, pub default_channel_administrator_rights: Option<ChatAdministratorRights>, pub affiliate_program: Option<AffiliateProgramInfo>, pub web_app_background_light_color: i32, pub web_app_background_dark_color: i32, pub web_app_header_light_color: i32, pub web_app_header_dark_color: i32, pub verification_parameters: Option<BotVerificationParameters>, pub can_get_revenue_statistics: bool, pub can_manage_emoji_status: bool, pub has_media_previews: bool, pub edit_commands_link: Option<InternalLinkType>, pub edit_description_link: Option<InternalLinkType>, pub edit_description_media_link: Option<InternalLinkType>, pub edit_settings_link: Option<InternalLinkType>,
}
Contains information about a bot

Fields

short_description: String

The text that is shown on the bot’s profile page and is sent together with the link when users share the bot

description: String

The text shown in the chat with the bot if the chat is empty

photo: Option<Photo>

Photo shown in the chat with the bot if the chat is empty; may be null

animation: Option<Animation>

Animation shown in the chat with the bot if the chat is empty; may be null

menu_button: Option<BotMenuButton>

Information about a button to show instead of the bot commands menu button; may be null if ordinary bot commands menu must be shown

commands: Vec<BotCommand>

List of the bot commands

privacy_policy_url: String

The HTTP link to the privacy policy of the bot. If empty, then /privacy command must be used if supported by the bot. If the command isn’t supported, then https:telegram.org/privacy-tpa must be opened

default_group_administrator_rights: Option<ChatAdministratorRights>

Default administrator rights for adding the bot to basic group and supergroup chats; may be null

default_channel_administrator_rights: Option<ChatAdministratorRights>

Default administrator rights for adding the bot to channels; may be null

affiliate_program: Option<AffiliateProgramInfo>

Information about the affiliate program of the bot; may be null if none

web_app_background_light_color: i32

Default light background color for bot Web Apps; -1 if not specified

web_app_background_dark_color: i32

Default dark background color for bot Web Apps; -1 if not specified

web_app_header_light_color: i32

Default light header color for bot Web Apps; -1 if not specified

web_app_header_dark_color: i32

Default dark header color for bot Web Apps; -1 if not specified

verification_parameters: Option<BotVerificationParameters>

Parameters of the verification that can be provided by the bot; may be null if none or the current user isn’t the owner of the bot

can_get_revenue_statistics: bool

True, if the bot’s revenue statistics are available to the current user

can_manage_emoji_status: bool

True, if the bot can manage emoji status of the current user

has_media_previews: bool

True, if the bot has media previews

edit_commands_link: Option<InternalLinkType>

The internal link, which can be used to edit bot commands; may be null

edit_description_link: Option<InternalLinkType>

The internal link, which can be used to edit bot description; may be null

edit_description_media_link: Option<InternalLinkType>

The internal link, which can be used to edit the photo or animation shown in the chat with the bot if the chat is empty; may be null

edit_settings_link: Option<InternalLinkType>

The internal link, which can be used to edit bot settings; may be null