pub struct BotMediaPreviewInfo {
pub previews: Vec<BotMediaPreview>,
pub language_codes: Vec<String>,
}Expand description
Contains a list of media previews of a bot for the given language and the list of languages for which the bot has dedicated previews
Fields
previews: Vec<BotMediaPreview>List of media previews
language_codes: Vec<String>List of language codes for which the bot has dedicated previews