pub struct BotVerificationParameters {
pub icon_custom_emoji_id: i64,
pub organization_name: String,
pub default_custom_description: Option<FormattedText>,
pub can_set_custom_description: bool,
}Expand description
Describes parameters of verification that is provided by a bot
Fields
icon_custom_emoji_id: i64Identifier of the custom emoji that is used as the verification sign
organization_name: StringName of the organization that provides verification
default_custom_description: Option<FormattedText>Default custom description of verification reason to be used as placeholder in setMessageSenderBotVerification; may be null if none
can_set_custom_description: boolTrue, if the bot is allowed to provide custom description for verified entities