pub struct BusinessBotRights {Show 14 fields
pub can_reply: bool,
pub can_read_messages: bool,
pub can_delete_sent_messages: bool,
pub can_delete_all_messages: bool,
pub can_edit_name: bool,
pub can_edit_bio: bool,
pub can_edit_profile_photo: bool,
pub can_edit_username: bool,
pub can_view_gifts_and_stars: bool,
pub can_sell_gifts: bool,
pub can_change_gift_settings: bool,
pub can_transfer_and_upgrade_gifts: bool,
pub can_transfer_stars: bool,
pub can_manage_stories: bool,
}Expand description
Describes rights of a business bot
Fields
can_reply: boolTrue, if the bot can send and edit messages in the private chats that had incoming messages in the last 24 hours
can_read_messages: boolTrue, if the bot can mark incoming private messages as read
can_delete_sent_messages: boolTrue, if the bot can delete sent messages
can_delete_all_messages: boolTrue, if the bot can delete any message
can_edit_name: boolTrue, if the bot can edit name of the business account
can_edit_bio: boolTrue, if the bot can edit bio of the business account
can_edit_profile_photo: boolTrue, if the bot can edit profile photo of the business account
can_edit_username: boolTrue, if the bot can edit username of the business account
can_view_gifts_and_stars: boolTrue, if the bot can view gifts and Telegram Star amount owned by the business account
can_sell_gifts: boolTrue, if the bot can sell regular gifts received by the business account
can_change_gift_settings: boolTrue, if the bot can change gift receiving settings of the business account
can_transfer_and_upgrade_gifts: boolTrue, if the bot can transfer and upgrade gifts received by the business account
can_transfer_stars: boolTrue, if the bot can transfer Telegram Stars received by the business account to account of the bot, or use them to upgrade and transfer gifts
can_manage_stories: boolTrue, if the bot can post, edit and delete stories