pub struct CanPostStoryResultMonthlyLimitExceeded {
pub retry_after: i32,
}Expand description
The monthly limit for the number of posted stories exceeded. The user needs to buy Telegram Premium or wait specified time
Fields
retry_after: i32Time left before the user can post the next story, in seconds