pub struct ChatBoostStatus {
pub boost_url: String,
pub applied_slot_ids: Vec<i32>,
pub level: i32,
pub gift_code_boost_count: i32,
pub boost_count: i32,
pub current_level_boost_count: i32,
pub next_level_boost_count: i32,
pub premium_member_count: i32,
pub premium_member_percentage: f64,
pub prepaid_giveaways: Vec<PrepaidGiveaway>,
}Expand description
Describes current boost status of a chat
Fields
boost_url: StringAn HTTP URL, which can be used to boost the chat
applied_slot_ids: Vec<i32>Identifiers of boost slots of the current user applied to the chat
level: i32Current boost level of the chat
gift_code_boost_count: i32The number of boosts received by the chat from created Telegram Premium gift codes and giveaways; always 0 if the current user isn’t an administrator in the chat
boost_count: i32The number of boosts received by the chat
current_level_boost_count: i32The number of boosts added to reach the current level
next_level_boost_count: i32The number of boosts needed to reach the next level; 0 if the next level isn’t available
Approximate number of Telegram Premium subscribers joined the chat; always 0 if the current user isn’t an administrator in the chat
A percentage of Telegram Premium subscribers joined the chat; always 0 if the current user isn’t an administrator in the chat
prepaid_giveaways: Vec<PrepaidGiveaway>The list of prepaid giveaways available for the chat; only for chat administrators