pub struct ChatInviteLink {Show 14 fields
pub invite_link: String,
pub name: String,
pub creator_user_id: i64,
pub date: i32,
pub edit_date: i32,
pub expiration_date: i32,
pub subscription_pricing: Option<StarSubscriptionPricing>,
pub member_limit: i32,
pub member_count: i32,
pub expired_member_count: i32,
pub pending_join_request_count: i32,
pub creates_join_request: bool,
pub is_primary: bool,
pub is_revoked: bool,
}Expand description
Contains a chat invite link
Fields
invite_link: StringChat invite link
name: StringName of the link
creator_user_id: i64User identifier of an administrator created the link
date: i32Point in time (Unix timestamp) when the link was created
edit_date: i32Point in time (Unix timestamp) when the link was last edited; 0 if never or unknown
expiration_date: i32Point in time (Unix timestamp) when the link will expire; 0 if never
subscription_pricing: Option<StarSubscriptionPricing>Information about subscription plan that is applied to the users joining the chat by the link; may be null if the link doesn’t require subscription
member_limit: i32The maximum number of members, which can join the chat using the link simultaneously; 0 if not limited. Always 0 if the link requires approval
member_count: i32Number of chat members, which joined the chat using the link
expired_member_count: i32Number of chat members, which joined the chat using the link, but have already left because of expired subscription; for subscription links only
pending_join_request_count: i32Number of pending join requests created using this link
creates_join_request: boolTrue, if the link only creates join request. If true, total number of joining members will be unlimited
is_primary: boolTrue, if the link is primary. Primary invite link can’t have name, expiration date, or usage limit. There is exactly one primary invite link for each administrator with can_invite_users right at a given time
is_revoked: boolTrue, if the link was revoked