pub struct ChatNotificationSettings {Show 16 fields
pub use_default_mute_for: bool,
pub mute_for: i32,
pub use_default_sound: bool,
pub sound_id: i64,
pub use_default_show_preview: bool,
pub show_preview: bool,
pub use_default_mute_stories: bool,
pub mute_stories: bool,
pub use_default_story_sound: bool,
pub story_sound_id: i64,
pub use_default_show_story_poster: bool,
pub show_story_poster: bool,
pub use_default_disable_pinned_message_notifications: bool,
pub disable_pinned_message_notifications: bool,
pub use_default_disable_mention_notifications: bool,
pub disable_mention_notifications: bool,
}Expand description
Contains information about notification settings for a chat or a forum topic
Fields
use_default_mute_for: boolIf true, the value for the relevant type of chat or the forum chat is used instead of mute_for
mute_for: i32Time left before notifications will be unmuted, in seconds
use_default_sound: boolIf true, the value for the relevant type of chat or the forum chat is used instead of sound_id
sound_id: i64Identifier of the notification sound to be played for messages; 0 if sound is disabled
use_default_show_preview: boolIf true, the value for the relevant type of chat or the forum chat is used instead of show_preview
show_preview: boolTrue, if message content must be displayed in notifications
use_default_mute_stories: boolIf true, the value for the relevant type of chat is used instead of mute_stories
mute_stories: boolTrue, if story notifications are disabled for the chat
use_default_story_sound: boolIf true, the value for the relevant type of chat is used instead of story_sound_id
story_sound_id: i64Identifier of the notification sound to be played for stories; 0 if sound is disabled
use_default_show_story_poster: boolIf true, the value for the relevant type of chat is used instead of show_story_poster
show_story_poster: boolTrue, if the chat that posted a story must be displayed in notifications
use_default_disable_pinned_message_notifications: boolIf true, the value for the relevant type of chat or the forum chat is used instead of disable_pinned_message_notifications
disable_pinned_message_notifications: boolIf true, notifications for incoming pinned messages will be created as for an ordinary unread message
use_default_disable_mention_notifications: boolIf true, the value for the relevant type of chat or the forum chat is used instead of disable_mention_notifications
disable_mention_notifications: boolIf true, notifications for messages with mentions will be created as for an ordinary unread message