pub struct Checklist {
pub title: FormattedText,
pub tasks: Vec<ChecklistTask>,
pub others_can_add_tasks: bool,
pub can_add_tasks: bool,
pub others_can_mark_tasks_as_done: bool,
pub can_mark_tasks_as_done: bool,
}Expand description
Describes a checklist
Fields
title: FormattedTextTitle of the checklist; may contain only Bold, Italic, Underline, Strikethrough, Spoiler, and CustomEmoji entities
tasks: Vec<ChecklistTask>List of tasks in the checklist
others_can_add_tasks: boolTrue, if users other than creator of the list can add tasks to the list
can_add_tasks: boolTrue, if the current user can add tasks to the list if they have Telegram Premium subscription
others_can_mark_tasks_as_done: boolTrue, if users other than creator of the list can mark tasks as done or not done. If true, then the checklist is called “group checklist”
can_mark_tasks_as_done: boolTrue, if the current user can mark tasks as done or not done if they have Telegram Premium subscription