pub struct ChecklistTask {
pub id: i32,
pub text: FormattedText,
pub completed_by: Option<MessageSender>,
pub completion_date: i32,
}Expand description
Describes a task in a checklist
Fields
id: i32Unique identifier of the task
text: FormattedTextText of the task; may contain only Bold, Italic, Underline, Strikethrough, Spoiler, CustomEmoji, Url, EmailAddress, Mention, Hashtag, Cashtag and PhoneNumber entities
completed_by: Option<MessageSender>Identifier of the user or chat that completed the task; may be null if the task isn’t completed yet
completion_date: i32Point in time (Unix timestamp) when the task was completed; 0 if the task isn’t completed