pub struct ConnectedAffiliateProgram {
pub url: String,
pub bot_user_id: i64,
pub parameters: AffiliateProgramParameters,
pub connection_date: i32,
pub is_disconnected: bool,
pub user_count: i64,
pub revenue_star_count: i64,
}Expand description
Describes an affiliate program that was connected to an affiliate
Fields
url: StringThe link that can be used to refer users if the program is still active
bot_user_id: i64User identifier of the bot created the program
parameters: AffiliateProgramParametersThe parameters of the affiliate program
connection_date: i32Point in time (Unix timestamp) when the affiliate program was connected
is_disconnected: boolTrue, if the program was canceled by the bot, or disconnected by the chat owner and isn’t available anymore
user_count: i64The number of users that used the affiliate program
revenue_star_count: i64The number of Telegram Stars that were earned by the affiliate program