pub struct ConnectedAffiliatePrograms {
pub total_count: i32,
pub programs: Vec<ConnectedAffiliateProgram>,
pub next_offset: String,
}Expand description
Represents a list of affiliate programs that were connected to an affiliate
Fields
total_count: i32The total number of affiliate programs that were connected to the affiliate
programs: Vec<ConnectedAffiliateProgram>The list of connected affiliate programs
next_offset: StringThe offset for the next request. If empty, then there are no more results