pub struct DirectMessagesChatTopic {
pub chat_id: i64,
pub id: i64,
pub sender_id: MessageSender,
pub order: i64,
pub can_send_unpaid_messages: bool,
pub is_marked_as_unread: bool,
pub unread_count: i64,
pub last_read_inbox_message_id: i64,
pub last_read_outbox_message_id: i64,
pub unread_reaction_count: i64,
pub last_message: Option<Message>,
pub draft_message: Option<DraftMessage>,
}Expand description
Contains information about a topic in a channel direct messages chat administered by the current user
Fields
chat_id: i64Identifier of the chat to which the topic belongs
id: i64Unique topic identifier
sender_id: MessageSenderIdentifier of the user or chat that sends the messages to the topic
order: i64A parameter used to determine order of the topic in the topic list. Topics must be sorted by the order in descending order
can_send_unpaid_messages: boolTrue, if the other party can send unpaid messages even if the chat has paid messages enabled
is_marked_as_unread: boolTrue, if the topic is marked as unread
unread_count: i64Number of unread messages in the chat
last_read_inbox_message_id: i64Identifier of the last read incoming message
last_read_outbox_message_id: i64Identifier of the last read outgoing message
unread_reaction_count: i64Number of messages with unread reactions in the chat
last_message: Option<Message>Last message in the topic; may be null if none or unknown
draft_message: Option<DraftMessage>A draft of a message in the topic; may be null if none