pub struct EmojiStatusTypeUpgradedGift {
pub upgraded_gift_id: i64,
pub gift_title: String,
pub gift_name: String,
pub model_custom_emoji_id: i64,
pub symbol_custom_emoji_id: i64,
pub backdrop_colors: UpgradedGiftBackdropColors,
}Expand description
An upgraded gift set as emoji status
Fields
upgraded_gift_id: i64Identifier of the upgraded gift
gift_title: StringThe title of the upgraded gift
gift_name: StringUnique name of the upgraded gift that can be used with internalLinkTypeUpgradedGift
model_custom_emoji_id: i64Custom emoji identifier of the model of the upgraded gift
symbol_custom_emoji_id: i64Custom emoji identifier of the symbol of the upgraded gift
backdrop_colors: UpgradedGiftBackdropColorsColors of the backdrop of the upgraded gift