pub struct FactCheck {
pub text: FormattedText,
pub country_code: String,
}Expand description
Describes a fact-check added to the message by an independent checker
Fields
text: FormattedTextText of the fact-check
country_code: StringA two-letter ISO 3166-1 alpha-2 country code of the country for which the fact-check is shown