pub struct ForumTopicInfo {
pub chat_id: i64,
pub forum_topic_id: i32,
pub name: String,
pub icon: ForumTopicIcon,
pub creation_date: i32,
pub creator_id: MessageSender,
pub is_general: bool,
pub is_outgoing: bool,
pub is_closed: bool,
pub is_hidden: bool,
pub is_name_implicit: bool,
}Expand description
Contains basic information about a forum topic
Fields
chat_id: i64Identifier of a forum supergroup chat or a chat with a bot to which the topic belongs
forum_topic_id: i32Forum topic identifier of the topic
name: StringName of the topic
icon: ForumTopicIconIcon of the topic
creation_date: i32Point in time (Unix timestamp) when the topic was created
creator_id: MessageSenderIdentifier of the creator of the topic
is_general: boolTrue, if the topic is the General topic
is_outgoing: boolTrue, if the topic was created by the current user
is_closed: boolTrue, if the topic is closed. If the topic is closed, then the user must have can_manage_topics administrator right in the supergroup or must be the creator of the topic to send messages there
True, if the topic is hidden above the topic list and closed; for General topic only
is_name_implicit: boolTrue, if the name of the topic wasn’t added explicitly