pub struct FoundPublicPosts {
pub messages: Vec<Message>,
pub next_offset: String,
pub search_limits: Option<PublicPostSearchLimits>,
pub are_limits_exceeded: bool,
}Expand description
Contains a list of messages found by a public post search
Fields
messages: Vec<Message>List of found public posts
next_offset: StringThe offset for the next request. If empty, then there are no more results
search_limits: Option<PublicPostSearchLimits>Updated public post search limits after the query; repeated requests with the same query will be free; may be null if they didn’t change
are_limits_exceeded: boolTrue, if the query has failed because search limits are exceeded. In this case search_limits.daily_free_query_count will be equal to 0