pub struct GiftAuctionAcquiredGift {
pub receiver_id: MessageSender,
pub date: i32,
pub star_count: i64,
pub auction_round_number: i32,
pub auction_round_position: i32,
pub unique_gift_number: i32,
pub text: FormattedText,
pub is_private: bool,
}Expand description
Represents a gift that was acquired by the current user on an auction
Fields
receiver_id: MessageSenderReceiver of the gift
date: i32Point in time (Unix timestamp) when the gift was acquired
star_count: i64The number of Telegram Stars that were paid for the gift
auction_round_number: i32Identifier of the auction round in which the gift was acquired
auction_round_position: i32Position of the user in the round among all auction participants
unique_gift_number: i32Unique number of the gift among gifts upgraded from the same gift after upgrade; 0 if yet unassigned
text: FormattedTextMessage added to the gift
is_private: boolTrue, if the sender and gift text are shown only to the gift receiver; otherwise, everyone will be able to see them