pub struct GiftForResale {
pub gift: UpgradedGift,
pub received_gift_id: String,
}Expand description
Describes a gift available for resale
Fields
gift: UpgradedGiftThe gift
received_gift_id: StringUnique identifier of the received gift for the current user; only for the gifts owned by the current user