pub struct GiftResaleParameters {
pub star_count: i64,
pub toncoin_cent_count: i64,
pub toncoin_only: bool,
}Expand description
Describes parameters of a unique gift available for resale
Fields
star_count: i64Resale price of the gift in Telegram Stars
toncoin_cent_count: i64Resale price of the gift in 1/100 of Toncoin
toncoin_only: boolTrue, if the gift can be bought only using Toncoins