pub struct GiftUpgradePreview {
pub models: Vec<UpgradedGiftModel>,
pub symbols: Vec<UpgradedGiftSymbol>,
pub backdrops: Vec<UpgradedGiftBackdrop>,
pub prices: Vec<GiftUpgradePrice>,
pub next_prices: Vec<GiftUpgradePrice>,
}Expand description
Contains examples of possible upgraded gifts for the given regular gift
Fields
models: Vec<UpgradedGiftModel>Examples of possible models that can be chosen for the gift after upgrade
symbols: Vec<UpgradedGiftSymbol>Examples of possible symbols that can be chosen for the gift after upgrade
backdrops: Vec<UpgradedGiftBackdrop>Examples of possible backdrops that can be chosen for the gift after upgrade
prices: Vec<GiftUpgradePrice>Examples of price for gift upgrade from the maximum price to the minimum price
next_prices: Vec<GiftUpgradePrice>Next changes for the price for gift upgrade with more granularity than in prices