pub struct GiftUpgradeVariants {
pub models: Vec<UpgradedGiftModel>,
pub symbols: Vec<UpgradedGiftSymbol>,
pub backdrops: Vec<UpgradedGiftBackdrop>,
}Expand description
Contains all possible variants of upgraded gifts for the given regular gift
Fields
models: Vec<UpgradedGiftModel>Models that can be chosen for the gift after upgrade
symbols: Vec<UpgradedGiftSymbol>Symbols that can be chosen for the gift after upgrade
backdrops: Vec<UpgradedGiftBackdrop>Backdrops that can be chosen for the gift after upgrade