pub struct GiftsForCrafting {
pub total_count: i32,
pub gifts: Vec<ReceivedGift>,
pub attribute_persistence_probabilities: Vec<AttributeCraftPersistenceProbability>,
pub next_offset: String,
}Expand description
Represents a list of gifts received by a user or a chat
Fields
total_count: i32The total number of received gifts
gifts: Vec<ReceivedGift>The list of gifts
attribute_persistence_probabilities: Vec<AttributeCraftPersistenceProbability>The 4 objects that describe probabilities of the crafted gift to have the backdrop or symbol of one of the original gifts for the cases when 1, 2, 3 or 4 gifts are used in the craft correspondingly
next_offset: StringThe offset for the next request. If empty, then there are no more results