pub struct GroupCall {Show 32 fields
pub id: i32,
pub unique_id: i64,
pub title: String,
pub invite_link: String,
pub paid_message_star_count: i64,
pub scheduled_start_date: i32,
pub enabled_start_notification: bool,
pub is_active: bool,
pub is_video_chat: bool,
pub is_live_story: bool,
pub is_rtmp_stream: bool,
pub is_joined: bool,
pub need_rejoin: bool,
pub is_owned: bool,
pub can_be_managed: bool,
pub participant_count: i32,
pub has_hidden_listeners: bool,
pub loaded_all_participants: bool,
pub message_sender_id: Option<MessageSender>,
pub recent_speakers: Vec<GroupCallRecentSpeaker>,
pub is_my_video_enabled: bool,
pub is_my_video_paused: bool,
pub can_enable_video: bool,
pub mute_new_participants: bool,
pub can_toggle_mute_new_participants: bool,
pub can_send_messages: bool,
pub are_messages_allowed: bool,
pub can_toggle_are_messages_allowed: bool,
pub can_delete_messages: bool,
pub record_duration: i32,
pub is_video_recorded: bool,
pub duration: i32,
}Expand description
Describes a group call
Fields
id: i32Group call identifier
unique_id: i64Persistent unique group call identifier
title: StringGroup call title; for video chats only
invite_link: StringInvite link for the group call; for group calls that aren’t bound to a chat. For video chats call getVideoChatInviteLink to get the link. For live stories in chats with username call getInternalLink with internalLinkTypeLiveStory
paid_message_star_count: i64The minimum number of Telegram Stars that must be paid by general participant for each sent message to the call; for live stories only
scheduled_start_date: i32Point in time (Unix timestamp) when the group call is expected to be started by an administrator; 0 if it is already active or was ended; for video chats only
enabled_start_notification: boolTrue, if the group call is scheduled and the current user will receive a notification when the group call starts; for video chats only
is_active: boolTrue, if the call is active
is_video_chat: boolTrue, if the call is bound to a chat
is_live_story: boolTrue, if the call is a live story of a chat
is_rtmp_stream: boolTrue, if the call is an RTMP stream instead of an ordinary video chat; for video chats and live stories only
is_joined: boolTrue, if the call is joined
need_rejoin: boolTrue, if user was kicked from the call because of network loss and the call needs to be rejoined
is_owned: boolTrue, if the user is the owner of the call and can end the call, change volume level of other users, or ban users there; for group calls that aren’t bound to a chat
can_be_managed: boolTrue, if the current user can manage the group call; for video chats and live stories only
participant_count: i32Number of participants in the group call
True, if group call participants, which are muted, aren’t returned in participant list; for video chats only
loaded_all_participants: boolTrue, if all group call participants are loaded
message_sender_id: Option<MessageSender>Message sender chosen to send messages to the group call; for live stories only; may be null if the call isn’t a live story
recent_speakers: Vec<GroupCallRecentSpeaker>At most 3 recently speaking users in the group call
is_my_video_enabled: boolTrue, if the current user’s video is enabled
is_my_video_paused: boolTrue, if the current user’s video is paused
can_enable_video: boolTrue, if the current user can broadcast video or share screen
mute_new_participants: boolTrue, if only group call administrators can unmute new participants; for video chats only
can_toggle_mute_new_participants: boolTrue, if the current user can enable or disable mute_new_participants setting; for video chats only
can_send_messages: boolTrue, if the current user can send messages to the group call
are_messages_allowed: boolTrue, if sending of messages is allowed in the group call
can_toggle_are_messages_allowed: boolTrue, if the current user can enable or disable sending of messages in the group call
can_delete_messages: boolTrue, if the user can delete messages in the group call
record_duration: i32Duration of the ongoing group call recording, in seconds; 0 if none. An updateGroupCall update is not triggered when value of this field changes, but the same recording goes on
is_video_recorded: boolTrue, if a video file is being recorded for the call
duration: i32Call duration, in seconds; for ended calls only