pub struct GroupCallMessage {
pub message_id: i32,
pub sender_id: MessageSender,
pub date: i32,
pub text: FormattedText,
pub paid_message_star_count: i64,
pub is_from_owner: bool,
pub can_be_deleted: bool,
}Expand description
Represents a message sent in a group call
Fields
message_id: i32Unique message identifier within the group call
sender_id: MessageSenderIdentifier of the sender of the message
date: i32Point in time (Unix timestamp) when the message was sent
text: FormattedTextText of the message. If empty, then the message is a paid reaction in a live story
paid_message_star_count: i64The number of Telegram Stars that were paid to send the message; for live stories only
is_from_owner: boolTrue, if the message is sent by the owner of the call and must be treated as a message of the maximum level; for live stories only
can_be_deleted: boolTrue, if the message can be deleted by the current user; for live stories only