pub struct GroupCallMessageLevel {
pub min_star_count: i64,
pub pin_duration: i32,
pub max_text_length: i32,
pub max_custom_emoji_count: i32,
pub first_color: i32,
pub second_color: i32,
pub background_color: i32,
}Expand description
Represents a level of features for a message sent in a live story group call
Fields
min_star_count: i64The minimum number of Telegram Stars required to get features of the level
pin_duration: i32The amount of time the message of this level will be pinned, in seconds
max_text_length: i32The maximum allowed length of the message text
max_custom_emoji_count: i32The maximum allowed number of custom emoji in the message text
first_color: i32The first color used to show the message text in the RGB format
second_color: i32The second color used to show the message text in the RGB format
background_color: i32Background color for the message the RGB format