pub struct InlineKeyboardButtonTypeCallbackWithPassword {
pub data: String,
}Expand description
A button that asks for the 2-step verification password of the current user and then sends a callback query to a bot
Fields
data: StringData to be sent to the bot via a callback query