pub struct InlineKeyboardButtonTypeLoginUrl {
pub url: String,
pub id: i64,
pub forward_text: String,
}Expand description
A button that opens a specified URL and automatically authorize the current user by calling getLoginUrlInfo
Fields
url: StringAn HTTP URL to pass to getLoginUrlInfo
id: i64Unique button identifier
forward_text: StringIf non-empty, new text of the button in forwarded messages