pub struct InputChatThemeGift {
pub name: String,
}Expand description
A theme based on an upgraded gift
Fields
name: StringName of the upgraded gift. A gift can be used only in one chat in a time. When the same gift is used in another chat, theme in the previous chat is reset to default