pub struct InputChecklist {
pub title: FormattedText,
pub tasks: Vec<InputChecklistTask>,
pub others_can_add_tasks: bool,
pub others_can_mark_tasks_as_done: bool,
}Expand description
Describes a checklist to be sent
Fields
title: FormattedTextTitle of the checklist; 1-getOption(“checklist_title_length_max”) characters. May contain only Bold, Italic, Underline, Strikethrough, Spoiler, and CustomEmoji entities
tasks: Vec<InputChecklistTask>List of tasks in the checklist; 1-getOption(“checklist_task_count_max”) tasks
others_can_add_tasks: boolTrue, if other users can add tasks to the list
others_can_mark_tasks_as_done: boolTrue, if other users can mark tasks as done or not done