pub struct InputMessageInvoice {Show 13 fields
pub invoice: Invoice,
pub title: String,
pub description: String,
pub photo_url: String,
pub photo_size: i32,
pub photo_width: i32,
pub photo_height: i32,
pub payload: String,
pub provider_token: String,
pub provider_data: String,
pub start_parameter: String,
pub paid_media: Option<InputPaidMedia>,
pub paid_media_caption: Option<FormattedText>,
}Expand description
A message with an invoice; can be used only by bots
Fields
invoice: InvoiceInvoice
title: StringProduct title; 1-32 characters
description: StringProduct description; 0-255 characters
photo_url: StringProduct photo URL; optional
photo_size: i32Product photo size
photo_width: i32Product photo width
photo_height: i32Product photo height
payload: StringThe invoice payload
provider_token: StringPayment provider token; may be empty for payments in Telegram Stars
provider_data: StringJSON-encoded data about the invoice, which will be shared with the payment provider
start_parameter: StringUnique invoice bot deep link parameter for the generation of this invoice. If empty, it would be possible to pay directly from forwards of the invoice message
paid_media: Option<InputPaidMedia>The content of paid media attached to the invoice; pass null if none
paid_media_caption: Option<FormattedText>Paid media caption; pass null to use an empty caption; 0-getOption(“message_caption_length_max”) characters