pub struct InputMessagePaidMedia {
pub star_count: i64,
pub paid_media: Vec<InputPaidMedia>,
pub caption: Option<FormattedText>,
pub show_caption_above_media: bool,
pub payload: String,
}Expand description
A message with paid media; can be used only in channel chats with supergroupFullInfo.has_paid_media_allowed
Fields
star_count: i64The number of Telegram Stars that must be paid to see the media; 1-getOption(“paid_media_message_star_count_max”)
paid_media: Vec<InputPaidMedia>The content of the paid media
caption: Option<FormattedText>Message caption; pass null to use an empty caption; 0-getOption(“message_caption_length_max”) characters
show_caption_above_media: boolTrue, if the caption must be shown above the media; otherwise, the caption must be shown below the media; not supported in secret chats
payload: StringBot-provided data for the paid media; bots only