pub struct InputMessagePhoto {
pub photo: InputFile,
pub thumbnail: Option<InputThumbnail>,
pub added_sticker_file_ids: Vec<i32>,
pub width: i32,
pub height: i32,
pub caption: Option<FormattedText>,
pub show_caption_above_media: bool,
pub self_destruct_type: Option<MessageSelfDestructType>,
pub has_spoiler: bool,
}Expand description
A photo message
Fields
photo: InputFilePhoto to send. The photo must be at most 10 MB in size. The photo’s width and height must not exceed 10000 in total. Width and height ratio must be at most 20
thumbnail: Option<InputThumbnail>Photo thumbnail to be sent; pass null to skip thumbnail uploading. The thumbnail is sent to the other party only in secret chats
added_sticker_file_ids: Vec<i32>File identifiers of the stickers added to the photo, if applicable
width: i32Photo width
height: i32Photo height
caption: Option<FormattedText>Photo caption; pass null to use an empty caption; 0-getOption(“message_caption_length_max”) characters
show_caption_above_media: boolTrue, if the caption must be shown above the photo; otherwise, the caption must be shown below the photo; not supported in secret chats
self_destruct_type: Option<MessageSelfDestructType>Photo self-destruct type; pass null if none; private chats only
has_spoiler: boolTrue, if the photo preview must be covered by a spoiler animation; not supported in secret chats