pub struct InputMessagePoll {
pub question: FormattedText,
pub options: Vec<FormattedText>,
pub is_anonymous: bool,
pub type: PollType,
pub open_period: i32,
pub close_date: i32,
pub is_closed: bool,
}Expand description
A message with a poll. Polls can’t be sent to secret chats and channel direct messages chats. Polls can be sent to a private chat only if the chat is a chat with a bot or the Saved Messages chat
Fields
question: FormattedTextPoll question; 1-255 characters (up to 300 characters for bots). Only custom emoji entities are allowed to be added and only by Premium users
options: Vec<FormattedText>List of poll answer options, 2-getOption(“poll_answer_count_max”) strings 1-100 characters each. Only custom emoji entities are allowed to be added and only by Premium users
is_anonymous: boolTrue, if the poll voters are anonymous. Non-anonymous polls can’t be sent or forwarded to channels
type: PollTypeType of the poll
open_period: i32Amount of time the poll will be active after creation, in seconds; for bots only
close_date: i32Point in time (Unix timestamp) when the poll will automatically be closed; for bots only
is_closed: boolTrue, if the poll needs to be sent already closed; for bots only