pub struct InputMessageReplyToExternalMessage {
pub chat_id: i64,
pub message_id: i64,
pub quote: Option<InputTextQuote>,
pub checklist_task_id: i32,
}Expand description
Describes a message to be replied that is from a different chat or a forum topic; not supported in secret chats
Fields
chat_id: i64The identifier of the chat to which the message to be replied belongs
message_id: i64The identifier of the message to be replied in the specified chat. A message can be replied in another chat or forum topic only if messageProperties.can_be_replied_in_another_chat
quote: Option<InputTextQuote>Quote from the message to be replied; pass null if none
checklist_task_id: i32Identifier of the checklist task in the message to be replied; pass 0 to reply to the whole message