pub struct InputMessageStakeDice {
pub state_hash: String,
pub stake_toncoin_amount: i64,
pub clear_draft: bool,
}Expand description
A stake dice message
Fields
state_hash: StringHash of the stake dice state. The state hash can be used only if it was received recently enough. Otherwise, a new state must be requested using getStakeDiceState
stake_toncoin_amount: i64The Toncoin amount that will be staked; in the smallest units of the currency. Must be in the range getOption(“stake_dice_stake_amount_min”)-getOption(“stake_dice_stake_amount_max”)
clear_draft: boolTrue, if the chat message draft must be deleted