pub struct InputPaidMediaTypeVideo {
pub cover: Option<InputFile>,
pub start_timestamp: i32,
pub duration: i32,
pub supports_streaming: bool,
}Expand description
The media is a video
Fields
cover: Option<InputFile>Cover of the video; pass null to skip cover uploading
start_timestamp: i32Timestamp from which the video playing must start, in seconds
duration: i32Duration of the video, in seconds
supports_streaming: boolTrue, if the video is expected to be streamed