InternalLinkTypeDirectMessagesChat

Struct InternalLinkTypeDirectMessagesChat 

pub struct InternalLinkTypeDirectMessagesChat {
    pub channel_username: String,
}
The link is a link to a channel direct messages chat by username of the channel. Call searchPublicChat with the given chat username to process the link. If the chat is found and is channel, open the direct messages chat of the channel

Fields

channel_username: String

Username of the channel