pub struct InternalLinkTypeGiftAuction {
pub auction_id: String,
}Expand description
The link is a link to a gift auction. Call getGiftAuctionState with the given auction identifier to process the link
Fields
auction_id: StringUnique identifier of the auction