pub struct InternalLinkTypeGiftCollection {
pub gift_owner_username: String,
pub collection_id: i32,
}Expand description
The link is a link to a gift collection. Call searchPublicChat with the given username, then call getReceivedGifts with the received gift owner identifier and the given collection identifier, then show the collection if received
Fields
gift_owner_username: StringUsername of the owner of the gift collection
collection_id: i32Gift collection identifier