pub struct InternalLinkTypeGroupCall {
pub invite_link: String,
}Expand description
The link is a link to a group call that isn’t bound to a chat. Use getGroupCallParticipants to get the list of group call participants and show them on the join group call screen. Call joinGroupCall with the given invite_link to join the call
Fields
invite_link: StringInternal representation of the invite link