pub struct InternalLinkTypeLiveStory {
pub story_poster_username: String,
}Expand description
The link is a link to a live story. Call searchPublicChat with the given chat username, then getChatActiveStories to get active stories in the chat, then find a live story among active stories of the chat, and then joinLiveStory to join the live story
Fields
story_poster_username: StringUsername of the poster of the story