pub struct InternalLinkTypeNewStory {
pub content_type: Option<StoryContentType>,
}Expand description
The link is a link to open the story posting interface
Fields
content_type: Option<StoryContentType>The type of the content of the story to post; may be null if unspecified