pub struct InternalLinkTypePremiumGiftPurchase {
pub referrer: String,
}Expand description
The link is a link to the screen for gifting Telegram Premium subscriptions to friends via inputInvoiceTelegram with telegramPaymentPurposePremiumGift payments or in-store purchases
Fields
referrer: StringReferrer specified in the link