InternalLinkTypeStarPurchase

Struct InternalLinkTypeStarPurchase 

pub struct InternalLinkTypeStarPurchase {
    pub star_count: i64,
    pub purpose: String,
}
The link is a link to the Telegram Star purchase section of the application

Fields

star_count: i64

The number of Telegram Stars that must be owned by the user

purpose: String

Purpose of Telegram Star purchase. Arbitrary string specified by the server, for example, “subs” if the Telegram Stars are required to extend channel subscriptions