InternalLinkTypeStoryAlbum

Struct InternalLinkTypeStoryAlbum 

pub struct InternalLinkTypeStoryAlbum {
    pub story_album_owner_username: String,
    pub story_album_id: i32,
}
The link is a link to an album of stories. Call searchPublicChat with the given username, then call getStoryAlbumStories with the received chat identifier and the given story album identifier, then show the story album if received

Fields

story_album_owner_username: String

Username of the owner of the story album

story_album_id: i32

Story album identifier