pub struct InviteGroupCallParticipantResultSuccess {
pub chat_id: i64,
pub message_id: i64,
}Expand description
The user was invited and a service message of the type messageGroupCall was sent which can be used in declineGroupCallInvitation to cancel the invitation
Fields
chat_id: i64Identifier of the chat with the invitation message
message_id: i64Identifier of the message