LinkPreview

Struct LinkPreview 

pub struct LinkPreview {
Show 13 fields pub url: String, pub display_url: String, pub site_name: String, pub title: String, pub description: FormattedText, pub author: String, pub type: LinkPreviewType, pub has_large_media: bool, pub show_large_media: bool, pub show_media_above_description: bool, pub skip_confirmation: bool, pub show_above_text: bool, pub instant_view_version: i32,
}
Describes a link preview

Fields

url: String

Original URL of the link

display_url: String

URL to display

site_name: String

Short name of the site (e.g., Google Docs, App Store)

title: String

Title of the content

description: FormattedText

Description of the content

author: String

Author of the content

type: LinkPreviewType

Type of the link preview

has_large_media: bool

True, if size of media in the preview can be changed

show_large_media: bool

True, if large media preview must be shown; otherwise, the media preview must be shown small and only the first frame must be shown for videos

show_media_above_description: bool

True, if media must be shown above link preview description; otherwise, the media must be shown below the description

skip_confirmation: bool

True, if there is no need to show an ordinary open URL confirmation, when opening the URL from the preview, because the URL is shown in the message text in clear

show_above_text: bool

True, if the link preview must be shown above message text; otherwise, the link preview must be shown below the message text

instant_view_version: i32

Version of instant view (currently, can be 1 or 2) for the web page; 0 if none