pub struct LinkPreviewTypeLiveStory {
pub story_poster_chat_id: i64,
pub story_id: i32,
}Expand description
The link is a link to a live story group call
Fields
story_poster_chat_id: i64The identifier of the chat that posted the story
story_id: i32Story identifier