pub struct LinkPreviewTypeVideoChat {
pub photo: Option<ChatPhoto>,
pub is_live_stream: bool,
pub joins_as_speaker: bool,
}Expand description
The link is a link to a video chat
Fields
photo: Option<ChatPhoto>Photo of the chat with the video chat; may be null if none
is_live_stream: boolTrue, if the video chat is expected to be a live stream in a channel or a broadcast group
joins_as_speaker: boolTrue, if the user can use the link to join the video chat without being muted by administrators