pub struct LoginUrlInfoRequestConfirmation {
pub url: String,
pub domain: String,
pub bot_user_id: i64,
pub request_write_access: bool,
pub request_phone_number_access: bool,
pub browser: String,
pub platform: String,
pub ip_address: String,
pub location: String,
}Expand description
An authorization confirmation dialog needs to be shown to the user
Fields
url: StringAn HTTP URL to be opened
domain: StringA domain of the URL
bot_user_id: i64User identifier of a bot linked with the website
request_write_access: boolTrue, if the user must be asked for the permission to the bot to send them messages
request_phone_number_access: boolTrue, if the user must be asked for the permission to share their phone number
browser: StringThe version of a browser used for the authorization; may be empty if irrelevant
platform: StringOperating system the browser is running on; may be empty if irrelevant
ip_address: StringIP address from which the authorization is performed, in human-readable format; may be empty if irrelevant
location: StringHuman-readable description of a country and a region from which the authorization is performed, based on the IP address; may be empty if irrelevant