pub struct MainWebApp {
pub url: String,
pub mode: WebAppOpenMode,
}Expand description
Contains information about the main Web App of a bot
Fields
url: StringURL of the Web App to open
mode: WebAppOpenModeThe mode in which the Web App must be opened