pub struct MessageChatOwnerLeft {
pub new_owner_user_id: i64,
}Expand description
The owner of the chat has left
Fields
new_owner_user_id: i64Identifier of the user who will become the new owner of the chat if the previous owner isn’t return; 0 if none