pub struct MessageChecklistTasksDone {
pub checklist_message_id: i64,
pub marked_as_done_task_ids: Vec<i32>,
pub marked_as_not_done_task_ids: Vec<i32>,
}Expand description
Some tasks from a checklist were marked as done or not done
Fields
checklist_message_id: i64Identifier of the message with the checklist; may be 0 or an identifier of a deleted message
marked_as_done_task_ids: Vec<i32>Identifiers of tasks that were marked as done
marked_as_not_done_task_ids: Vec<i32>Identifiers of tasks that were marked as not done