pub struct MessageGiftedPremium {
pub gifter_user_id: i64,
pub receiver_user_id: i64,
pub text: FormattedText,
pub currency: String,
pub amount: i64,
pub cryptocurrency: String,
pub cryptocurrency_amount: i64,
pub month_count: i32,
pub day_count: i32,
pub sticker: Option<Sticker>,
}Expand description
Telegram Premium was gifted to a user
Fields
gifter_user_id: i64The identifier of a user who gifted Telegram Premium; 0 if the gift was anonymous or is outgoing
receiver_user_id: i64The identifier of a user who received Telegram Premium; 0 if the gift is incoming
text: FormattedTextMessage added to the gifted Telegram Premium by the sender
currency: StringCurrency for the paid amount
amount: i64The paid amount, in the smallest units of the currency
cryptocurrency: StringCryptocurrency used to pay for the gift; may be empty if none
cryptocurrency_amount: i64The paid amount, in the smallest units of the cryptocurrency; 0 if none
month_count: i32Number of months the Telegram Premium subscription will be active after code activation; 0 if the number of months isn’t integer
day_count: i32Number of days the Telegram Premium subscription will be active
sticker: Option<Sticker>A sticker to be shown in the message; may be null if unknown