pub struct MessageGiftedStars {
pub gifter_user_id: i64,
pub receiver_user_id: i64,
pub currency: String,
pub amount: i64,
pub cryptocurrency: String,
pub cryptocurrency_amount: i64,
pub star_count: i64,
pub transaction_id: String,
pub sticker: Option<Sticker>,
}Expand description
Telegram Stars were gifted to a user
Fields
gifter_user_id: i64The identifier of a user who gifted Telegram Stars; 0 if the gift was anonymous or is outgoing
receiver_user_id: i64The identifier of a user who received Telegram Stars; 0 if the gift is incoming
currency: StringCurrency for the paid amount
amount: i64The paid amount, in the smallest units of the currency
cryptocurrency: StringCryptocurrency used to pay for the gift; may be empty if none
cryptocurrency_amount: i64The paid amount, in the smallest units of the cryptocurrency; 0 if none
star_count: i64Number of Telegram Stars that were gifted
transaction_id: StringIdentifier of the transaction for Telegram Stars purchase; for receiver only
sticker: Option<Sticker>A sticker to be shown in the message; may be null if unknown