pub struct MessageGiveawayCompleted {
pub giveaway_message_id: i64,
pub winner_count: i32,
pub is_star_giveaway: bool,
pub unclaimed_prize_count: i32,
}Expand description
A giveaway without public winners has been completed for the chat
Fields
giveaway_message_id: i64Identifier of the message with the giveaway; may be 0 or an identifier of a deleted message
winner_count: i32Number of winners in the giveaway
is_star_giveaway: boolTrue, if the giveaway is a Telegram Star giveaway
unclaimed_prize_count: i32Number of undistributed prizes; for Telegram Premium giveaways only