pub struct MessageGiveawayPrizeStars {
pub star_count: i64,
pub transaction_id: String,
pub boosted_chat_id: i64,
pub giveaway_message_id: i64,
pub is_unclaimed: bool,
pub sticker: Option<Sticker>,
}Expand description
A Telegram Stars were received by the current user from a giveaway
Fields
star_count: i64Number of Telegram Stars that were received
transaction_id: StringIdentifier of the transaction for Telegram Stars credit
boosted_chat_id: i64Identifier of the supergroup or channel chat, which was automatically boosted by the winners of the giveaway
giveaway_message_id: i64Identifier of the message with the giveaway in the boosted chat; may be 0 or an identifier of a deleted message
is_unclaimed: boolTrue, if the corresponding winner wasn’t chosen and the Telegram Stars were received by the owner of the boosted chat
sticker: Option<Sticker>A sticker to be shown in the message; may be null if unknown