pub struct MessageGiveawayWinners {
pub boosted_chat_id: i64,
pub giveaway_message_id: i64,
pub additional_chat_count: i32,
pub actual_winners_selection_date: i32,
pub only_new_members: bool,
pub was_refunded: bool,
pub prize: GiveawayPrize,
pub prize_description: String,
pub winner_count: i32,
pub winner_user_ids: Vec<i64>,
pub unclaimed_prize_count: i32,
}Expand description
A giveaway with public winners has been completed for the chat
Fields
boosted_chat_id: i64Identifier of the supergroup or channel chat, which was automatically boosted by the winners of the giveaway
giveaway_message_id: i64Identifier of the message with the giveaway in the boosted chat
additional_chat_count: i32Number of other chats that participated in the giveaway
actual_winners_selection_date: i32Point in time (Unix timestamp) when the winners were selected. May be bigger than winners selection date specified in parameters of the giveaway
only_new_members: boolTrue, if only new members of the chats were eligible for the giveaway
was_refunded: boolTrue, if the giveaway was canceled and was fully refunded
prize: GiveawayPrizePrize of the giveaway
prize_description: StringAdditional description of the giveaway prize
winner_count: i32Total number of winners in the giveaway
winner_user_ids: Vec<i64>Up to 100 user identifiers of the winners of the giveaway
unclaimed_prize_count: i32Number of undistributed prizes; for Telegram Premium giveaways only