MessageGroupCall

Struct MessageGroupCall 

pub struct MessageGroupCall {
    pub unique_id: i64,
    pub is_active: bool,
    pub was_missed: bool,
    pub is_video: bool,
    pub duration: i32,
    pub other_participant_ids: Vec<MessageSender>,
}
A message with information about a group call not bound to a chat. If the message is incoming, the call isn’t active, isn’t missed, and has no duration, and getOption(“can_accept_calls”) is true, then incoming call screen must be shown to the user. Use getGroupCallParticipants to show current group call participants on the screen. Use joinGroupCall to accept the call or declineGroupCallInvitation to decline it. If the call become active or missed, then the call screen must be hidden

Fields

unique_id: i64

Persistent unique group call identifier

is_active: bool

True, if the call is active, i.e. the called user joined the call

was_missed: bool

True, if the called user missed or declined the call

is_video: bool

True, if the call is a video call

duration: i32

Call duration, in seconds; for left calls only

other_participant_ids: Vec<MessageSender>

Identifiers of some other call participants