pub struct MessageInvoice {
pub product_info: ProductInfo,
pub currency: String,
pub total_amount: i64,
pub start_parameter: String,
pub is_test: bool,
pub need_shipping_address: bool,
pub receipt_message_id: i64,
pub paid_media: Option<PaidMedia>,
pub paid_media_caption: Option<FormattedText>,
}Expand description
A message with an invoice from a bot. Use getInternalLink with internalLinkTypeBotStart to share the invoice
Fields
product_info: ProductInfoInformation about the product
currency: StringCurrency for the product price
total_amount: i64Product total price in the smallest units of the currency
start_parameter: StringUnique invoice bot start_parameter to be passed to getInternalLink
is_test: boolTrue, if the invoice is a test invoice
need_shipping_address: boolTrue, if the shipping address must be specified
receipt_message_id: i64The identifier of the message with the receipt, after the product has been purchased
paid_media: Option<PaidMedia>Extended media attached to the invoice; may be null if none
paid_media_caption: Option<FormattedText>Extended media caption; may be null if none