pub struct MessagePaymentSuccessfulBot {
pub currency: String,
pub total_amount: i64,
pub subscription_until_date: i32,
pub is_recurring: bool,
pub is_first_recurring: bool,
pub invoice_payload: String,
pub shipping_option_id: String,
pub order_info: Option<OrderInfo>,
pub telegram_payment_charge_id: String,
pub provider_payment_charge_id: String,
}Expand description
A payment has been received by the bot or the business account
Fields
currency: StringCurrency for price of the product
total_amount: i64Total price for the product, in the smallest units of the currency
subscription_until_date: i32Point in time (Unix timestamp) when the subscription will expire; 0 if unknown or the payment isn’t recurring
is_recurring: boolTrue, if this is a recurring payment
is_first_recurring: boolTrue, if this is the first recurring payment
invoice_payload: StringInvoice payload
shipping_option_id: StringIdentifier of the shipping option chosen by the user; may be empty if not applicable; for bots only
order_info: Option<OrderInfo>Information about the order; may be null; for bots only
telegram_payment_charge_id: StringTelegram payment identifier
provider_payment_charge_id: StringProvider payment identifier