pub struct MessagePremiumGiftCode {
pub creator_id: Option<MessageSender>,
pub text: FormattedText,
pub is_from_giveaway: bool,
pub is_unclaimed: bool,
pub currency: String,
pub amount: i64,
pub cryptocurrency: String,
pub cryptocurrency_amount: i64,
pub month_count: i32,
pub day_count: i32,
pub sticker: Option<Sticker>,
pub code: String,
}Expand description
A Telegram Premium gift code was created for the user
Fields
creator_id: Option<MessageSender>Identifier of a chat or a user who created the gift code; may be null if unknown
text: FormattedTextMessage added to the gift
is_from_giveaway: boolTrue, if the gift code was created for a giveaway
is_unclaimed: boolTrue, if the winner for the corresponding Telegram Premium subscription wasn’t chosen
currency: StringCurrency for the paid amount; empty if unknown
amount: i64The paid amount, in the smallest units of the currency; 0 if unknown
cryptocurrency: StringCryptocurrency used to pay for the gift; may be empty if none or unknown
cryptocurrency_amount: i64The paid amount, in the smallest units of the cryptocurrency; 0 if unknown
month_count: i32Number of months the Telegram Premium subscription will be active after code activation; 0 if the number of months isn’t integer
day_count: i32Number of days the Telegram Premium subscription will be active after code activation
sticker: Option<Sticker>A sticker to be shown in the message; may be null if unknown
code: StringThe gift code