pub struct MessageSendOptions {
pub suggested_post_info: Option<InputSuggestedPostInfo>,
pub disable_notification: bool,
pub from_background: bool,
pub protect_content: bool,
pub allow_paid_broadcast: bool,
pub paid_message_star_count: i64,
pub update_order_of_installed_sticker_sets: bool,
pub scheduling_state: Option<MessageSchedulingState>,
pub effect_id: i64,
pub sending_id: i32,
pub only_preview: bool,
}Expand description
Options to be used when a message is sent
Fields
suggested_post_info: Option<InputSuggestedPostInfo>Information about the suggested post; pass null if none. For messages to channel direct messages chat only. Applicable only to sendMessage and addOffer
disable_notification: boolPass true to disable notification for the message
from_background: boolPass true if the message is sent from the background
protect_content: boolPass true if the content of the message must be protected from forwarding and saving; for bots only
allow_paid_broadcast: boolPass true to allow the message to ignore regular broadcast limits for a small fee; for bots only
paid_message_star_count: i64The number of Telegram Stars the user agreed to pay to send the messages
update_order_of_installed_sticker_sets: boolPass true if the user explicitly chosen a sticker or a custom emoji from an installed sticker set; applicable only to sendMessage and sendMessageAlbum
scheduling_state: Option<MessageSchedulingState>Message scheduling state; pass null to send message immediately. Messages sent to a secret chat, to a chat with paid messages, to a channel direct messages chat, live location messages and self-destructing messages can’t be scheduled
effect_id: i64Identifier of the effect to apply to the message; pass 0 if none; applicable only to sendMessage, sendMessageAlbum in private chats and forwardMessages with one message to private chats
sending_id: i32Non-persistent identifier, which will be returned back in messageSendingStatePending object and can be used to match sent messages and corresponding updateNewMessage updates
only_preview: boolPass true to get a fake message instead of actually sending them