pub struct MessageStakeDice {
pub initial_state: Option<DiceStickers>,
pub final_state: Option<DiceStickers>,
pub value: i32,
pub stake_toncoin_amount: i64,
pub prize_toncoin_amount: i64,
}Expand description
A stake dice message. The dice value is randomly generated by the server
Fields
initial_state: Option<DiceStickers>The animated stickers with the initial dice animation; may be null if unknown. The update updateMessageContent will be sent when the sticker became known
final_state: Option<DiceStickers>The animated stickers with the final dice animation; may be null if unknown. The update updateMessageContent will be sent when the sticker became known
value: i32The dice value. If the value is 0, then the dice don’t have final state yet
stake_toncoin_amount: i64The Toncoin amount that was staked; in the smallest units of the currency
prize_toncoin_amount: i64The Toncoin amount that was gained from the roll; in the smallest units of the currency; -1 if the dice don’t have final state yet