MessageUpgradedGift

Struct MessageUpgradedGift 

pub struct MessageUpgradedGift {
Show 14 fields pub gift: UpgradedGift, pub sender_id: Option<MessageSender>, pub receiver_id: MessageSender, pub origin: UpgradedGiftOrigin, pub received_gift_id: String, pub is_saved: bool, pub can_be_transferred: bool, pub was_transferred: bool, pub transfer_star_count: i64, pub drop_original_details_star_count: i64, pub next_transfer_date: i32, pub next_resale_date: i32, pub export_date: i32, pub craft_date: i32,
}
An upgraded gift was received or sent by the current user, or the current user was notified about a channel gift

Fields

gift: UpgradedGift

The gift

sender_id: Option<MessageSender>

Sender of the gift; may be null for anonymous gifts

receiver_id: MessageSender

Receiver of the gift

origin: UpgradedGiftOrigin

Origin of the upgraded gift

received_gift_id: String

Unique identifier of the received gift for the current user; only for the receiver of the gift

is_saved: bool

True, if the gift is displayed on the user’s or the channel’s profile page; only for the receiver of the gift

can_be_transferred: bool

True, if the gift can be transferred to another owner; only for the receiver of the gift

was_transferred: bool

True, if the gift has already been transferred to another owner; only for the receiver of the gift

transfer_star_count: i64

Number of Telegram Stars that must be paid to transfer the upgraded gift; only for the receiver of the gift

drop_original_details_star_count: i64

Number of Telegram Stars that must be paid to drop original details of the upgraded gift; 0 if not available; only for the receiver of the gift

next_transfer_date: i32

Point in time (Unix timestamp) when the gift can be transferred to another owner; can be in the past; 0 if the gift can be transferred immediately or transfer isn’t possible; only for the receiver of the gift

next_resale_date: i32

Point in time (Unix timestamp) when the gift can be resold to another user; can be in the past; 0 if the gift can’t be resold; only for the receiver of the gift

export_date: i32

Point in time (Unix timestamp) when the gift can be transferred to the TON blockchain as an NFT; can be in the past; 0 if NFT export isn’t possible; only for the receiver of the gift

craft_date: i32

Point in time (Unix timestamp) when the gift can be used to craft another gift can be in the past; only for the receiver of the gift