pub struct MessageVideo {
pub video: Video,
pub alternative_videos: Vec<AlternativeVideo>,
pub storyboards: Vec<VideoStoryboard>,
pub cover: Option<Photo>,
pub start_timestamp: i32,
pub caption: FormattedText,
pub show_caption_above_media: bool,
pub has_spoiler: bool,
pub is_secret: bool,
}Expand description
A video message
Fields
video: VideoThe video description
alternative_videos: Vec<AlternativeVideo>Alternative qualities of the video
storyboards: Vec<VideoStoryboard>Available storyboards for the video
cover: Option<Photo>Cover of the video; may be null if none
start_timestamp: i32Timestamp from which the video playing must start, in seconds
caption: FormattedTextVideo caption
show_caption_above_media: boolTrue, if the caption must be shown above the video; otherwise, the caption must be shown below the video
has_spoiler: boolTrue, if the video preview must be covered by a spoiler animation
is_secret: boolTrue, if the video thumbnail must be blurred and the video must be shown only while tapped