pub struct PaidReactor {
pub sender_id: Option<MessageSender>,
pub star_count: i64,
pub is_top: bool,
pub is_me: bool,
pub is_anonymous: bool,
}Expand description
Contains information about a user who added paid reactions
Fields
sender_id: Option<MessageSender>Identifier of the user or chat that added the reactions; may be null for anonymous reactors that aren’t the current user
star_count: i64Number of Telegram Stars added
is_top: boolTrue, if the reactor is one of the most active reactors; may be false if the reactor is the current user
is_me: boolTrue, if the paid reaction was added by the current user
is_anonymous: boolTrue, if the reactor is anonymous