pub struct PaymentFormTypeRegular {
pub invoice: Invoice,
pub payment_provider_user_id: i64,
pub payment_provider: PaymentProvider,
pub additional_payment_options: Vec<PaymentOption>,
pub saved_order_info: Option<OrderInfo>,
pub saved_credentials: Vec<SavedCredentials>,
pub can_save_credentials: bool,
pub need_password: bool,
}Expand description
The payment form is for a regular payment
Fields
invoice: InvoiceFull information about the invoice
payment_provider_user_id: i64User identifier of the payment provider bot
payment_provider: PaymentProviderInformation about the payment provider
additional_payment_options: Vec<PaymentOption>The list of additional payment options
saved_order_info: Option<OrderInfo>Saved server-side order information; may be null
saved_credentials: Vec<SavedCredentials>The list of saved payment credentials
can_save_credentials: boolTrue, if the user can choose to save credentials
need_password: boolTrue, if the user will be able to save credentials, if sets up a 2-step verification password