pub struct PaymentReceiptTypeRegular {
pub payment_provider_user_id: i64,
pub invoice: Invoice,
pub order_info: Option<OrderInfo>,
pub shipping_option: Option<ShippingOption>,
pub credentials_title: String,
pub tip_amount: i64,
}Expand description
The payment was done using a third-party payment provider
Fields
payment_provider_user_id: i64User identifier of the payment provider bot
invoice: InvoiceInformation about the invoice
order_info: Option<OrderInfo>Order information; may be null
shipping_option: Option<ShippingOption>Chosen shipping option; may be null
credentials_title: StringTitle of the saved credentials chosen by the buyer
tip_amount: i64The amount of tip chosen by the buyer in the smallest units of the currency