pub struct PremiumGiftCodeInfo {
pub creator_id: Option<MessageSender>,
pub creation_date: i32,
pub is_from_giveaway: bool,
pub giveaway_message_id: i64,
pub month_count: i32,
pub day_count: i32,
pub user_id: i64,
pub use_date: i32,
}Expand description
Contains information about a Telegram Premium gift code
Fields
creator_id: Option<MessageSender>Identifier of a chat or a user who created the gift code; may be null if unknown. If null and the code is from messagePremiumGiftCode message, then creator_id from the message can be used
creation_date: i32Point in time (Unix timestamp) when the code was created
is_from_giveaway: boolTrue, if the gift code was created for a giveaway
giveaway_message_id: i64Identifier of the corresponding giveaway message in the creator_id chat; may be 0 or an identifier of a deleted message
month_count: i32Number of months the Telegram Premium subscription will be active after code activation; 0 if the number of months isn’t integer
day_count: i32Number of days the Telegram Premium subscription will be active after code activation
user_id: i64Identifier of a user for which the code was created; 0 if none
use_date: i32Point in time (Unix timestamp) when the code was activated; 0 if none