pub struct PremiumGiftPaymentOption {
pub currency: String,
pub amount: i64,
pub star_count: i64,
pub discount_percentage: i32,
pub month_count: i32,
pub store_product_id: String,
pub sticker: Option<Sticker>,
}Expand description
Describes an option for gifting Telegram Premium to a user. Use telegramPaymentPurposePremiumGift for out-of-store payments or payments in Telegram Stars
Fields
currency: StringISO 4217 currency code for the payment
amount: i64The amount to pay, in the smallest units of the currency
star_count: i64The alternative Telegram Star amount to pay; 0 if payment in Telegram Stars is not possible
discount_percentage: i32The discount associated with this option, as a percentage
month_count: i32Number of months the Telegram Premium subscription will be active
store_product_id: StringIdentifier of the store product associated with the option
sticker: Option<Sticker>A sticker to be shown along with the option; may be null if unknown