pub struct PremiumGiftPaymentOptions {
pub options: Vec<PremiumGiftPaymentOption>,
}Expand description
Contains a list of options for gifting Telegram Premium to a user
Fields
options: Vec<PremiumGiftPaymentOption>The list of options sorted by Telegram Premium subscription duration