pub struct PremiumGiveawayPaymentOption {
pub currency: String,
pub amount: i64,
pub winner_count: i32,
pub month_count: i32,
pub store_product_id: String,
pub store_product_quantity: i32,
}Expand description
Describes an option for creating of Telegram Premium giveaway or manual distribution of Telegram Premium among chat members. Use telegramPaymentPurposePremiumGiftCodes or telegramPaymentPurposePremiumGiveaway for out-of-store payments
Fields
currency: StringISO 4217 currency code for Telegram Premium gift code payment
amount: i64The amount to pay, in the smallest units of the currency
winner_count: i32Number of users which will be able to activate the gift codes
month_count: i32Number of months the Telegram Premium subscription will be active
store_product_id: StringIdentifier of the store product associated with the option; may be empty if none
store_product_quantity: i32Number of times the store product must be paid