pub struct PreparedInlineMessage {
pub inline_query_id: i64,
pub result: InlineQueryResult,
pub chat_types: TargetChatTypes,
}Expand description
Represents a ready to send inline message. Use sendInlineQueryResultMessage to send the message
Fields
inline_query_id: i64Unique identifier of the inline query to pass to sendInlineQueryResultMessage
result: InlineQueryResultResulted inline message of the query
chat_types: TargetChatTypesTypes of the chats to which the message can be sent