pub struct PushMessageContentInviteVideoChatParticipants {
pub is_current_user: bool,
}Expand description
An invitation of participants to a video chat or live stream
Fields
is_current_user: boolTrue, if the current user was invited to the video chat or the live stream