pub struct PushMessageContentUpgradedGift {
pub is_upgrade: bool,
pub is_prepaid_upgrade: bool,
}Expand description
A message with an upgraded gift
Fields
is_upgrade: boolTrue, if the gift was obtained by upgrading of a previously received gift; otherwise, if is_prepaid_upgrade == false, then this is a transferred or resold gift
is_prepaid_upgrade: boolTrue, if the message is about completion of prepaid upgrade of the gift instead of actual receiving of a new gift