pub struct ReceivedGifts {
pub total_count: i32,
pub gifts: Vec<ReceivedGift>,
pub are_notifications_enabled: bool,
pub next_offset: String,
}Expand description
Represents a list of gifts received by a user or a chat
Fields
total_count: i32The total number of received gifts
gifts: Vec<ReceivedGift>The list of gifts
are_notifications_enabled: boolTrue, if notifications about new gifts of the owner are enabled
next_offset: StringThe offset for the next request. If empty, then there are no more results