pub struct ReportStoryResultOptionRequired {
pub title: String,
pub options: Vec<ReportOption>,
}Expand description
The user must choose an option to report the story and repeat request with the chosen option
Fields
title: StringTitle for the option choice
options: Vec<ReportOption>List of available options