pub struct ScopeNotificationSettings {
pub mute_for: i32,
pub sound_id: i64,
pub show_preview: bool,
pub use_default_mute_stories: bool,
pub mute_stories: bool,
pub story_sound_id: i64,
pub show_story_poster: bool,
pub disable_pinned_message_notifications: bool,
pub disable_mention_notifications: bool,
}Expand description
Contains information about notification settings for several chats
Fields
mute_for: i32Time left before notifications will be unmuted, in seconds
sound_id: i64Identifier of the notification sound to be played; 0 if sound is disabled
show_preview: boolTrue, if message content must be displayed in notifications
use_default_mute_stories: boolIf true, story notifications are received only for the first 5 chats from topChatCategoryUsers regardless of the value of mute_stories
mute_stories: boolTrue, if story notifications are disabled
story_sound_id: i64Identifier of the notification sound to be played for stories; 0 if sound is disabled
show_story_poster: boolTrue, if the chat that posted a story must be displayed in notifications
disable_pinned_message_notifications: boolTrue, if notifications for incoming pinned messages will be created as for an ordinary unread message
disable_mention_notifications: boolTrue, if notifications for messages with mentions will be created as for an ordinary unread message