pub struct SponsoredChat {
pub unique_id: i64,
pub chat_id: i64,
pub sponsor_info: String,
pub additional_info: String,
}Expand description
Describes a sponsored chat
Fields
unique_id: i64Unique identifier of this result
chat_id: i64Chat identifier
sponsor_info: StringAdditional optional information about the sponsor to be shown along with the chat
additional_info: StringIf non-empty, additional information about the sponsored chat to be shown along with the chat