pub struct StakeDiceState {
pub state_hash: String,
pub stake_toncoin_amount: i64,
pub suggested_stake_toncoin_amounts: Vec<i64>,
pub current_streak: i32,
pub prize_per_mille: Vec<i32>,
pub streak_prize_per_mille: i32,
}Expand description
Describes state of the stake dice
Fields
state_hash: StringHash of the state to use for sending the next dice; may be empty if the stake dice can’t be sent by the current user
stake_toncoin_amount: i64The Toncoin amount that was staked in the previous roll; in the smallest units of the currency
suggested_stake_toncoin_amounts: Vec<i64>The amounts of Toncoins that are suggested to be staked; in the smallest units of the currency
current_streak: i32The number of rolled sixes towards the streak; 0-2
prize_per_mille: Vec<i32>The number of Toncoins received by the user for each 1000 Toncoins staked if the dice outcome is 1-6 correspondingly; may be empty if the stake dice can’t be sent by the current user
streak_prize_per_mille: i32The number of Toncoins received by the user for each 1000 Toncoins staked if the dice outcome is 6 three times in a row with the same stake