pub struct StarGiveawayWinnerOption {
pub winner_count: i32,
pub won_star_count: i64,
pub is_default: bool,
}Expand description
Describes an option for the number of winners of a Telegram Star giveaway
Fields
winner_count: i32The number of users that will be chosen as winners
won_star_count: i64The number of Telegram Stars that will be won by the winners of the giveaway
is_default: boolTrue, if the option must be chosen by default