pub struct StarPaymentOption {
pub currency: String,
pub amount: i64,
pub star_count: i64,
pub store_product_id: String,
pub is_additional: bool,
}Expand description
Describes an option for buying Telegram Stars. Use telegramPaymentPurposeStars for out-of-store payments
Fields
currency: StringISO 4217 currency code for the payment
amount: i64The amount to pay, in the smallest units of the currency
star_count: i64Number of Telegram Stars that will be purchased
store_product_id: StringIdentifier of the store product associated with the option; may be empty if none
is_additional: boolTrue, if the option must be shown only in the full list of payment options