pub struct StarRevenueStatus {
pub total_amount: StarAmount,
pub current_amount: StarAmount,
pub available_amount: StarAmount,
pub withdrawal_enabled: bool,
pub next_withdrawal_in: i32,
}Expand description
Contains information about Telegram Stars earned by a user or a chat
Fields
total_amount: StarAmountTotal Telegram Star amount earned
current_amount: StarAmountThe Telegram Star amount that isn’t withdrawn yet
available_amount: StarAmountThe Telegram Star amount that is available for withdrawal
withdrawal_enabled: boolTrue, if Telegram Stars can be withdrawn now or later
next_withdrawal_in: i32Time left before the next withdrawal can be started, in seconds; 0 if withdrawal can be started now