pub struct StarSubscription {
pub id: String,
pub chat_id: i64,
pub expiration_date: i32,
pub is_canceled: bool,
pub is_expiring: bool,
pub pricing: StarSubscriptionPricing,
pub type: StarSubscriptionType,
}Expand description
Contains information about subscription to a channel chat, a bot, or a business account that was paid in Telegram Stars
Fields
id: StringUnique identifier of the subscription
chat_id: i64Identifier of the chat that is subscribed
expiration_date: i32Point in time (Unix timestamp) when the subscription will expire or expired
is_canceled: boolTrue, if the subscription was canceled
is_expiring: boolTrue, if the subscription expires soon and there are no enough Telegram Stars on the user’s balance to extend it
pricing: StarSubscriptionPricingThe subscription plan
type: StarSubscriptionTypeType of the subscription