pub struct StarSubscriptionTypeBot {
pub is_canceled_by_bot: bool,
pub title: String,
pub photo: Photo,
pub invoice_link: String,
}Expand description
Describes a subscription in a bot or a business account
Fields
is_canceled_by_bot: boolTrue, if the subscription was canceled by the bot and can’t be extended
title: StringSubscription invoice title
photo: PhotoSubscription invoice photo
invoice_link: StringThe link to the subscription invoice