pub struct StarSubscriptionTypeChannel {
pub can_reuse: bool,
pub invite_link: String,
}Expand description
Describes a subscription to a channel chat
Fields
can_reuse: boolTrue, if the subscription is active and the user can use the method reuseStarSubscription to join the subscribed chat again
invite_link: StringThe invite link that can be used to renew the subscription if it has been expired; may be empty, if the link isn’t available anymore