pub struct StarTransaction {
pub id: String,
pub star_amount: StarAmount,
pub is_refund: bool,
pub date: i32,
pub type: StarTransactionType,
}Expand description
Represents a transaction changing the amount of owned Telegram Stars
Fields
id: StringUnique identifier of the transaction
star_amount: StarAmountThe amount of added owned Telegram Stars; negative for outgoing transactions
is_refund: boolTrue, if the transaction is a refund of a previous transaction
date: i32Point in time (Unix timestamp) when the transaction was completed
type: StarTransactionTypeType of the transaction