pub struct StarTransactionTypeBotInvoicePurchase {
pub user_id: i64,
pub product_info: ProductInfo,
}Expand description
The transaction is a purchase of a product from a bot or a business account by the current user; relevant for regular users only
Fields
user_id: i64Identifier of the bot or the business account user who created the invoice
product_info: ProductInfoInformation about the bought product