pub struct StarTransactionTypeBotInvoiceSale {
pub user_id: i64,
pub product_info: ProductInfo,
pub invoice_payload: String,
pub affiliate: Option<AffiliateInfo>,
}Expand description
The transaction is a sale of a product by the bot; relevant for bots only
Fields
user_id: i64Identifier of the user who bought the product
product_info: ProductInfoInformation about the bought product
invoice_payload: StringInvoice payload
affiliate: Option<AffiliateInfo>Information about the affiliate which received commission from the transaction; may be null if none