pub struct StarTransactionTypeBotPaidMediaPurchase {
pub user_id: i64,
pub media: Vec<PaidMedia>,
}Expand description
The transaction is a purchase of paid media from a bot or a business account by the current user; relevant for regular users only
Fields
user_id: i64Identifier of the bot or the business account user who sent the paid media
media: Vec<PaidMedia>The bought media if the transaction wasn’t refunded