pub struct StarTransactionTypeBotPaidMediaSale {
pub user_id: i64,
pub media: Vec<PaidMedia>,
pub payload: String,
pub affiliate: Option<AffiliateInfo>,
}Expand description
The transaction is a sale of paid media by the bot or a business account managed by the bot; relevant for bots only
Fields
user_id: i64Identifier of the user who bought the media
media: Vec<PaidMedia>The bought media
payload: StringBot-provided payload
affiliate: Option<AffiliateInfo>Information about the affiliate which received commission from the transaction; may be null if none