pub struct StarTransactionTypeBotSubscriptionPurchase {
pub user_id: i64,
pub subscription_period: i32,
pub product_info: ProductInfo,
}Expand description
The transaction is a purchase of a subscription from a bot or a business account by the current user; relevant for regular users only
Fields
user_id: i64Identifier of the bot or the business account user who created the subscription link
subscription_period: i32The number of seconds between consecutive Telegram Star debitings
product_info: ProductInfoInformation about the bought subscription