pub struct StarTransactionTypeBotSubscriptionSale {
pub user_id: i64,
pub subscription_period: i32,
pub product_info: ProductInfo,
pub invoice_payload: String,
pub affiliate: Option<AffiliateInfo>,
}Expand description
The transaction is a sale of a subscription by the bot; relevant for bots only
Fields
user_id: i64Identifier of the user who bought the subscription
subscription_period: i32The number of seconds between consecutive Telegram Star debitings
product_info: ProductInfoInformation about the bought subscription
invoice_payload: StringInvoice payload
affiliate: Option<AffiliateInfo>Information about the affiliate which received commission from the transaction; may be null if none