pub struct StarTransactionTypeChannelPaidMediaPurchase {
pub chat_id: i64,
pub message_id: i64,
pub media: Vec<PaidMedia>,
}Expand description
The transaction is a purchase of paid media from a channel by the current user; relevant for regular users only
Fields
chat_id: i64Identifier of the channel chat that sent the paid media
message_id: i64Identifier of the corresponding message with paid media; may be 0 or an identifier of a deleted message
media: Vec<PaidMedia>The bought media if the transaction wasn’t refunded