pub struct StarTransactionTypeChannelPaidReactionReceive {
pub user_id: i64,
pub message_id: i64,
}Expand description
The transaction is a receiving of a paid reaction to a message by the channel chat; relevant for channel chats only
Fields
user_id: i64Identifier of the user who added the paid reaction
message_id: i64Identifier of the reacted message; may be 0 or an identifier of a deleted message