pub struct StarTransactionTypeChannelPaidReactionSend {
pub chat_id: i64,
pub message_id: i64,
}Expand description
The transaction is a sending of a paid reaction to a message in a channel chat by the current user; relevant for regular users only
Fields
chat_id: i64Identifier of the channel chat
message_id: i64Identifier of the reacted message; may be 0 or an identifier of a deleted message