pub struct StarTransactionTypeChannelSubscriptionPurchase {
pub chat_id: i64,
pub subscription_period: i32,
}Expand description
The transaction is a purchase of a subscription to a channel chat by the current user; relevant for regular users only
Fields
chat_id: i64Identifier of the channel chat that created the subscription
subscription_period: i32The number of seconds between consecutive Telegram Star debitings