pub struct StarTransactionTypeChannelSubscriptionSale {
pub user_id: i64,
pub subscription_period: i32,
}Expand description
The transaction is a sale of a subscription by the channel chat; relevant for channel chats only
Fields
user_id: i64Identifier of the user who bought the subscription
subscription_period: i32The number of seconds between consecutive Telegram Star debitings