pub struct StarTransactionTypeFragmentWithdrawal {
pub withdrawal_state: Option<RevenueWithdrawalState>,
}Expand description
The transaction is a withdrawal of earned Telegram Stars to Fragment; relevant for regular users, bots, supergroup and channel chats only
Fields
withdrawal_state: Option<RevenueWithdrawalState>State of the withdrawal; may be null for refunds from Fragment