pub struct StarTransactionTypeGiftAuctionBid {
pub owner_id: MessageSender,
pub gift: Gift,
}Expand description
The transaction is a bid on a gift auction; relevant for regular users only
Fields
owner_id: MessageSenderIdentifier of the user who will receive the gift
gift: GiftThe gift