pub struct StarTransactionTypeGiftPurchase {
pub owner_id: MessageSender,
pub gift: Gift,
}Expand description
The transaction is a purchase of a regular gift; relevant for regular users and bots only
Fields
owner_id: MessageSenderIdentifier of the user or the channel that received the gift
gift: GiftThe gift