pub struct StarTransactionTypeGiftTransfer {
pub owner_id: MessageSender,
pub gift: UpgradedGift,
}Expand description
The transaction is a transfer of an upgraded gift; relevant for regular users only
Fields
owner_id: MessageSenderIdentifier of the user or the channel that received the gift
gift: UpgradedGiftThe gift