pub struct StarTransactionTypeGiftUpgradePurchase {
pub owner_id: MessageSender,
pub gift: Gift,
}Expand description
The transaction is a purchase of an upgrade of a gift owned by another user or channel; relevant for regular users only
Fields
owner_id: MessageSenderOwner of the upgraded gift
gift: GiftThe gift