pub struct StarTransactionTypeGiveawayDeposit {
pub chat_id: i64,
pub giveaway_message_id: i64,
}Expand description
The transaction is a deposit of Telegram Stars from a giveaway; relevant for regular users only
Fields
chat_id: i64Identifier of a supergroup or a channel chat that created the giveaway
giveaway_message_id: i64Identifier of the message with the giveaway; may be 0 or an identifier of a deleted message