pub struct StarTransactionTypePaidGroupCallMessageReceive {
pub sender_id: MessageSender,
pub commission_per_mille: i32,
pub commission_star_amount: StarAmount,
}Expand description
The transaction is a receiving of a paid group call message; relevant for regular users and channel chats only
Fields
sender_id: MessageSenderIdentifier of the sender of the message
commission_per_mille: i32The number of Telegram Stars received by the Telegram for each 1000 Telegram Stars paid for message sending
commission_star_amount: StarAmountThe Telegram Star amount that was received by Telegram; can be negative for refunds