pub struct StarTransactionTypePremiumPurchase {
pub user_id: i64,
pub month_count: i32,
pub sticker: Option<Sticker>,
}Expand description
The transaction is a purchase of Telegram Premium subscription; relevant for regular users and bots only
Fields
user_id: i64Identifier of the user who received the Telegram Premium subscription
month_count: i32Number of months the Telegram Premium subscription will be active
sticker: Option<Sticker>A sticker to be shown in the transaction information; may be null if unknown