pub struct StarTransactionTypeSuggestedPostPaymentReceive {
pub user_id: i64,
}Expand description
The transaction is a receiving of a payment for a suggested post by the channel chat; relevant for channel chats only
Fields
user_id: i64Identifier of the user who paid for the suggested post