pub struct StarTransactionTypeSuggestedPostPaymentSend {
pub chat_id: i64,
}Expand description
The transaction is a payment for a suggested post; relevant for regular users only
Fields
chat_id: i64Identifier of the channel chat that posted the post