pub struct StarTransactionTypeUpgradedGiftSale {
pub user_id: i64,
pub gift: UpgradedGift,
pub commission_per_mille: i32,
pub commission_star_amount: StarAmount,
pub via_offer: bool,
}Expand description
The transaction is a sale of an upgraded gift; relevant for regular users only
Fields
user_id: i64Identifier of the user who bought the gift
gift: UpgradedGiftThe gift
commission_per_mille: i32The number of Telegram Stars received by the Telegram for each 1000 Telegram Stars received by the seller of the gift
commission_star_amount: StarAmountThe Telegram Star amount that was received by Telegram; can be negative for refunds
via_offer: boolTrue, if the gift was sold through a purchase offer