pub struct StarTransactionTypeUserDeposit {
pub user_id: i64,
pub sticker: Option<Sticker>,
}Expand description
The transaction is a deposit of Telegram Stars by another user; relevant for regular users only
Fields
user_id: i64Identifier of the user who gifted Telegram Stars; 0 if the user was anonymous
sticker: Option<Sticker>The sticker to be shown in the transaction information; may be null if unknown