pub struct StartLiveStoryResultFail {
pub error_type: CanPostStoryResult,
}Expand description
The live story failed to post with an error to be handled
Fields
error_type: CanPostStoryResultType of the error; other error types may be returned as regular errors