pub struct StorePaymentPurposeGiftedStars {
pub user_id: i64,
pub currency: String,
pub amount: i64,
pub star_count: i64,
}Expand description
The user buying Telegram Stars for other users
Fields
user_id: i64Identifier of the user to which Telegram Stars are gifted
currency: StringISO 4217 currency code of the payment currency
amount: i64Paid amount, in the smallest units of the currency
star_count: i64Number of bought Telegram Stars