pub struct StorePaymentPurposePremiumGift {
pub currency: String,
pub amount: i64,
pub user_id: i64,
pub text: FormattedText,
}Expand description
The user gifting Telegram Premium to another user
Fields
currency: StringISO 4217 currency code of the payment currency
amount: i64Paid amount, in the smallest units of the currency
user_id: i64Identifiers of the user which will receive Telegram Premium
text: FormattedTextText to show along with the gift codes; 0-getOption(“gift_text_length_max”) characters. Only Bold, Italic, Underline, Strikethrough, Spoiler, and CustomEmoji entities are allowed