pub struct StorePaymentPurposeStars {
pub currency: String,
pub amount: i64,
pub star_count: i64,
pub chat_id: i64,
}Expand description
The user buying Telegram Stars
Fields
currency: StringISO 4217 currency code of the payment currency
amount: i64Paid amount, in the smallest units of the currency
star_count: i64Number of bought Telegram Stars
chat_id: i64Identifier of the chat that is supposed to receive the Telegram Stars; pass 0 if none