pub struct Story {Show 27 fields
pub id: i32,
pub poster_chat_id: i64,
pub poster_id: Option<MessageSender>,
pub date: i32,
pub is_being_posted: bool,
pub is_being_edited: bool,
pub is_edited: bool,
pub is_posted_to_chat_page: bool,
pub is_visible_only_for_self: bool,
pub can_be_added_to_album: bool,
pub can_be_deleted: bool,
pub can_be_edited: bool,
pub can_be_forwarded: bool,
pub can_be_replied: bool,
pub can_set_privacy_settings: bool,
pub can_toggle_is_posted_to_chat_page: bool,
pub can_get_statistics: bool,
pub can_get_interactions: bool,
pub has_expired_viewers: bool,
pub repost_info: Option<StoryRepostInfo>,
pub interaction_info: Option<StoryInteractionInfo>,
pub chosen_reaction_type: Option<ReactionType>,
pub privacy_settings: StoryPrivacySettings,
pub content: StoryContent,
pub areas: Vec<StoryArea>,
pub caption: FormattedText,
pub album_ids: Vec<i32>,
}Expand description
Represents a story
Fields
id: i32Unique story identifier among stories posted by the given chat
poster_chat_id: i64Identifier of the chat that posted the story
poster_id: Option<MessageSender>Identifier of the user or chat that posted the story; may be null if the story is posted on behalf of the poster_chat_id
date: i32Point in time (Unix timestamp) when the story was published
is_being_posted: boolTrue, if the story is being posted by the current user
is_being_edited: boolTrue, if the story is being edited by the current user
is_edited: boolTrue, if the story was edited
is_posted_to_chat_page: boolTrue, if the story is saved in the profile of the chat that posted it and will be available there after expiration
is_visible_only_for_self: boolTrue, if the story is visible only for the current user
can_be_added_to_album: boolTrue, if the story can be added to an album using createStoryAlbum and addStoryAlbumStories
can_be_deleted: boolTrue, if the story can be deleted
can_be_edited: boolTrue, if the story can be edited
can_be_forwarded: boolTrue, if the story can be forwarded as a message or reposted as a story. Otherwise, screenshotting and saving of the story content must be also forbidden
can_be_replied: boolTrue, if the story can be replied in the chat with the user who posted the story
can_set_privacy_settings: boolTrue, if the story privacy settings can be changed
can_toggle_is_posted_to_chat_page: boolTrue, if the story’s is_posted_to_chat_page value can be changed
can_get_statistics: boolTrue, if the story statistics are available through getStoryStatistics
can_get_interactions: boolTrue, if interactions with the story can be received through getStoryInteractions
has_expired_viewers: boolTrue, if users viewed the story can’t be received, because the story has expired more than getOption(“story_viewers_expiration_delay”) seconds ago
repost_info: Option<StoryRepostInfo>Information about the original story; may be null if the story wasn’t reposted
interaction_info: Option<StoryInteractionInfo>Information about interactions with the story; may be null if the story isn’t owned or there were no interactions
chosen_reaction_type: Option<ReactionType>Type of the chosen reaction; may be null if none
privacy_settings: StoryPrivacySettingsPrivacy rules affecting story visibility; may be approximate for non-owned stories
content: StoryContentContent of the story
areas: Vec<StoryArea>Clickable areas to be shown on the story content
caption: FormattedTextCaption of the story
album_ids: Vec<i32>Identifiers of story albums to which the story is added; only for manageable stories