pub struct StoryVideo {
pub duration: f64,
pub width: i32,
pub height: i32,
pub has_stickers: bool,
pub is_animation: bool,
pub minithumbnail: Option<Minithumbnail>,
pub thumbnail: Option<Thumbnail>,
pub preload_prefix_size: i32,
pub cover_frame_timestamp: f64,
pub video: File,
}Expand description
Describes a video file posted as a story
Fields
duration: f64Duration of the video, in seconds
width: i32Video width
height: i32Video height
has_stickers: boolTrue, if stickers were added to the video. The list of corresponding sticker sets can be received using getAttachedStickerSets
is_animation: boolTrue, if the video has no sound
minithumbnail: Option<Minithumbnail>Video minithumbnail; may be null
thumbnail: Option<Thumbnail>Video thumbnail in JPEG or MPEG4 format; may be null
preload_prefix_size: i32Size of file prefix, which is expected to be preloaded, in bytes
cover_frame_timestamp: f64Timestamp of the frame used as video thumbnail
video: FileFile containing the video