pub struct SuggestedActionCustom {
pub name: String,
pub title: FormattedText,
pub description: FormattedText,
pub url: String,
}Expand description
A custom suggestion to be shown at the top of the chat list
Fields
name: StringUnique name of the suggestion
title: FormattedTextTitle of the suggestion
description: FormattedTextDescription of the suggestion
url: StringThe link to open when the suggestion is clicked