SuggestedActionSetLoginEmailAddress

Struct SuggestedActionSetLoginEmailAddress 

pub struct SuggestedActionSetLoginEmailAddress {
    pub can_be_hidden: bool,
}
Suggests the user to add login email address. Call isLoginEmailAddressRequired, and then setLoginEmailAddress or checkLoginEmailAddressCode to change the login email address

Fields

can_be_hidden: bool

True, if the suggested action can be hidden using hideSuggestedAction. Otherwise, the user must not be able to use the app without setting up the email address