pub struct SuggestedPostPriceStar {
pub star_count: i64,
}Expand description
Describes price of a suggested post in Telegram Stars
Fields
star_count: i64The Telegram Star amount expected to be paid for the post; getOption(“suggested_post_star_count_min”)-getOption(“suggested_post_star_count_max”)