pub struct TargetChatTypes {
pub allow_user_chats: bool,
pub allow_bot_chats: bool,
pub allow_group_chats: bool,
pub allow_channel_chats: bool,
}Expand description
Describes allowed types for the target chat
Fields
allow_user_chats: boolTrue, if private chats with ordinary users are allowed
allow_bot_chats: boolTrue, if private chats with other bots are allowed
allow_group_chats: boolTrue, if basic group and supergroup chats are allowed
allow_channel_chats: boolTrue, if channel chats are allowed