pub struct TonRevenueStatistics {
pub revenue_by_day_graph: StatisticalGraph,
pub status: TonRevenueStatus,
pub usd_rate: f64,
}Expand description
A detailed statistics about Toncoins earned by the current user
Fields
revenue_by_day_graph: StatisticalGraphA graph containing amount of revenue in a given day
status: TonRevenueStatusAmount of earned revenue
usd_rate: f64Current conversion rate of nanotoncoin to USD cents