pub struct TonTransaction {
pub id: String,
pub ton_amount: i64,
pub is_refund: bool,
pub date: i32,
pub type: TonTransactionType,
}Expand description
Represents a transaction changing the amount of owned Toncoins
Fields
id: StringUnique identifier of the transaction
ton_amount: i64The amount of added owned Toncoins; negative for outgoing transactions
is_refund: boolTrue, if the transaction is a refund of a previous transaction
date: i32Point in time (Unix timestamp) when the transaction was completed
type: TonTransactionTypeType of the transaction