pub struct TonTransactionTypeFragmentDeposit {
pub is_gift: bool,
pub sticker: Option<Sticker>,
}Expand description
The transaction is a deposit of Toncoins from Fragment
Fields
is_gift: boolTrue, if the transaction is a gift from another user
sticker: Option<Sticker>The sticker to be shown in the transaction information; may be null if unknown