pub struct TonTransactionTypeSuggestedPostPayment {
pub chat_id: i64,
}Expand description
The transaction is a payment for a suggested post
Fields
chat_id: i64Identifier of the channel chat that posted the post