pub struct TonTransactionTypeUpgradedGiftSale {
pub user_id: i64,
pub gift: UpgradedGift,
pub commission_per_mille: i32,
pub commission_toncoin_amount: i64,
pub via_offer: bool,
}Expand description
The transaction is a sale of an upgraded gift
Fields
user_id: i64Identifier of the user who bought the gift
gift: UpgradedGiftThe gift
commission_per_mille: i32The number of Toncoins received by the Telegram for each 1000 Toncoins received by the seller of the gift
commission_toncoin_amount: i64The Toncoin amount that was received by the Telegram; in the smallest units of the currency
via_offer: boolTrue, if the gift was sold through a purchase offer