pub struct UpdateApplicationVerificationRequired {
pub verification_id: i64,
pub nonce: String,
pub cloud_project_number: i64,
}Expand description
A request can’t be completed unless application verification is performed; for official mobile applications only. The method setApplicationVerificationToken must be called once the verification is completed or failed
Fields
verification_id: i64Unique identifier for the verification process
nonce: StringUnique base64url-encoded nonce for the classic Play Integrity verification (https:developer.android.com/google/play/integrity/classic) for Android, or a unique string to compare with verify_nonce field from a push notification for iOS
cloud_project_number: i64Cloud project number to pass to the Play Integrity API on Android