pub struct UpdateDirectMessagesChatTopic {
pub topic: DirectMessagesChatTopic,
}Expand description
Basic information about a topic in a channel direct messages chat administered by the current user has changed. This update is guaranteed to come before the topic identifier is returned to the application
Fields
topic: DirectMessagesChatTopicNew data about the topic