pub struct UpdateForumTopic {
pub chat_id: i64,
pub forum_topic_id: i32,
pub is_pinned: bool,
pub last_read_inbox_message_id: i64,
pub last_read_outbox_message_id: i64,
pub unread_mention_count: i32,
pub unread_reaction_count: i32,
pub notification_settings: ChatNotificationSettings,
pub draft_message: Option<DraftMessage>,
}Expand description
Information about a topic in a forum chat was changed
Fields
chat_id: i64Chat identifier
forum_topic_id: i32Forum topic identifier of the topic
is_pinned: boolTrue, if the topic is pinned in the topic list
last_read_inbox_message_id: i64Identifier of the last read incoming message
last_read_outbox_message_id: i64Identifier of the last read outgoing message
unread_mention_count: i32Number of unread messages with a mention/reply in the topic
unread_reaction_count: i32Number of messages with unread reactions in the topic
notification_settings: ChatNotificationSettingsNotification settings for the topic
draft_message: Option<DraftMessage>A draft of a message in the topic; may be null if none