pub struct UpdateGroupCallMessageLevels {
pub levels: Vec<GroupCallMessageLevel>,
}Expand description
The levels of live story group call messages have changed
Fields
levels: Vec<GroupCallMessageLevel>New description of the levels in decreasing order of groupCallMessageLevel.min_star_count