pub struct UpdateGroupCallVerificationState {
pub group_call_id: i32,
pub generation: i32,
pub emojis: Vec<String>,
}Expand description
The verification state of an encrypted group call has changed; for group calls not bound to a chat only
Fields
group_call_id: i32Identifier of the group call
generation: i32The call state generation to which the emoji corresponds. If generation is different for two users, then their emoji may be also different
emojis: Vec<String>Group call state fingerprint represented as 4 emoji; may be empty if the state isn’t verified yet