pub struct UpdateMessageSendSucceeded {
pub message: Message,
pub old_message_id: i64,
}Expand description
A message has been successfully sent
Fields
message: MessageThe sent message. Almost any field of the new message can be different from the corresponding field of the original message. For example, the field scheduling_state may change, making the message scheduled, or non-scheduled
old_message_id: i64The previous temporary message identifier