pub struct UpdateNewBusinessCallbackQuery {
pub id: i64,
pub sender_user_id: i64,
pub connection_id: String,
pub message: BusinessMessage,
pub chat_instance: i64,
pub payload: CallbackQueryPayload,
}Expand description
A new incoming callback query from a business message; for bots only
Fields
id: i64Unique query identifier
sender_user_id: i64Identifier of the user who sent the query
connection_id: StringUnique identifier of the business connection
message: BusinessMessageThe message from the business account from which the query originated
chat_instance: i64An identifier uniquely corresponding to the chat a message was sent to
payload: CallbackQueryPayloadQuery payload