pub struct UpdateNewGroupCallPaidReaction {
pub group_call_id: i32,
pub sender_id: MessageSender,
pub star_count: i64,
}Expand description
A new paid reaction was received in a live story group call
Fields
group_call_id: i32Identifier of the group call
sender_id: MessageSenderIdentifier of the sender of the reaction
star_count: i64The number of Telegram Stars that were paid to send the reaction