pub struct UpdatePendingTextMessage {
pub chat_id: i64,
pub forum_topic_id: i32,
pub draft_id: i64,
pub text: FormattedText,
}Expand description
A new pending text message was received in a chat with a bot. The message must be shown in the chat for at most getOption(“pending_text_message_period”) seconds, replace any other pending message with the same draft_id, and be deleted whenever any incoming message from the bot in the message thread is received
Fields
chat_id: i64Chat identifier
forum_topic_id: i32The forum topic identifier in which the message will be sent; 0 if none
draft_id: i64Unique identifier of the message draft within the message thread
text: FormattedTextText of the pending message