pub struct UpdateStakeDiceState {
pub state: StakeDiceState,
}Expand description
The stake dice state has changed
Fields
state: StakeDiceStateThe new state. The state can be used only if it was received recently enough. Otherwise, a new state must be requested using getStakeDiceState