pub struct UpdateStarRevenueStatus {
pub owner_id: MessageSender,
pub status: StarRevenueStatus,
}Expand description
The Telegram Star revenue earned by a user or a chat has changed. If Telegram Star transaction screen of the chat is opened, then getStarTransactions may be called to fetch new transactions
Fields
owner_id: MessageSenderIdentifier of the owner of the Telegram Stars
status: StarRevenueStatusNew Telegram Star revenue status