pub struct UpdateTonRevenueStatus {
pub status: TonRevenueStatus,
}Expand description
The Toncoin revenue earned by the current user has changed. If Toncoin transaction screen of the chat is opened, then getTonTransactions may be called to fetch new transactions
Fields
status: TonRevenueStatusNew Toncoin revenue status