pub struct UpdateTopicMessageCount {
pub chat_id: i64,
pub topic_id: MessageTopic,
pub message_count: i32,
}Expand description
Number of messages in a topic has changed; for Saved Messages and channel direct messages chat topics only
Fields
chat_id: i64Identifier of the chat in topic of which the number of messages has changed
topic_id: MessageTopicIdentifier of the topic
message_count: i32Approximate number of messages in the topic