pub struct UpdateTrustedMiniAppBots {
pub bot_user_ids: Vec<i64>,
}Expand description
Lists of bots which Mini Apps must be allowed to read text from clipboard and must be opened without a warning
Fields
bot_user_ids: Vec<i64>List of user identifiers of the bots; the corresponding users may not be sent using updateUser updates and may not be accessible