UpgradedGiftValueInfo

Struct UpgradedGiftValueInfo 

pub struct UpgradedGiftValueInfo {
Show 14 fields pub currency: String, pub value: i64, pub is_value_average: bool, pub initial_sale_date: i32, pub initial_sale_star_count: i64, pub initial_sale_price: i64, pub last_sale_date: i32, pub last_sale_price: i64, pub is_last_sale_on_fragment: bool, pub minimum_price: i64, pub average_sale_price: i64, pub telegram_listed_gift_count: i32, pub fragment_listed_gift_count: i32, pub fragment_url: String,
}
Contains information about value of an upgraded gift

Fields

currency: String

ISO 4217 currency code of the currency in which the prices are represented

value: i64

Estimated value of the gift; in the smallest units of the currency

is_value_average: bool

True, if the value is calculated as average value of similar sold gifts. Otherwise, it is based on the sale price of the gift

initial_sale_date: i32

Point in time (Unix timestamp) when the corresponding regular gift was originally purchased

initial_sale_star_count: i64

The Telegram Star amount that was paid for the gift

initial_sale_price: i64

Initial price of the gift; in the smallest units of the currency

last_sale_date: i32

Point in time (Unix timestamp) when the upgraded gift was purchased last time; 0 if never

last_sale_price: i64

Last purchase price of the gift; in the smallest units of the currency; 0 if the gift has never been resold

is_last_sale_on_fragment: bool

True, if the last sale was completed on Fragment

minimum_price: i64

The current minimum price of gifts upgraded from the same gift; in the smallest units of the currency; 0 if there are no such gifts

average_sale_price: i64

The average sale price in the last month of gifts upgraded from the same gift; in the smallest units of the currency; 0 if there were no such sales

telegram_listed_gift_count: i32

Number of gifts upgraded from the same gift being resold on Telegram

fragment_listed_gift_count: i32

Number of gifts upgraded from the same gift being resold on Fragment

fragment_url: String

The HTTPS link to the Fragment for the gift; may be empty if there are no such gifts being sold on Fragment