pub struct UserAuctionBid {
pub star_count: i64,
pub bid_date: i32,
pub next_bid_star_count: i64,
pub owner_id: MessageSender,
pub was_returned: bool,
}Expand description
Describes a bid of the current user in an auction
Fields
star_count: i64The number of Telegram Stars that were put in the bid
bid_date: i32Point in time (Unix timestamp) when the bid was made
next_bid_star_count: i64The minimum number of Telegram Stars that can be put for the next bid
owner_id: MessageSenderIdentifier of the user or the chat that will receive the auctioned item. If the auction is opened in context of another user or chat, then a warning is supposed to be shown to the current user
was_returned: boolTrue, if the bid was returned to the user, because it was outbid and can’t win anymore