pub struct UserFullInfo {Show 30 fields
pub personal_photo: Option<ChatPhoto>,
pub photo: Option<ChatPhoto>,
pub public_photo: Option<ChatPhoto>,
pub block_list: Option<BlockList>,
pub can_be_called: bool,
pub supports_video_calls: bool,
pub has_private_calls: bool,
pub has_private_forwards: bool,
pub has_restricted_voice_and_video_note_messages: bool,
pub has_posted_to_profile_stories: bool,
pub has_sponsored_messages_enabled: bool,
pub need_phone_number_privacy_exception: bool,
pub set_chat_background: bool,
pub bio: Option<FormattedText>,
pub birthdate: Option<Birthdate>,
pub personal_chat_id: i64,
pub gift_count: i32,
pub group_in_common_count: i32,
pub incoming_paid_message_star_count: i64,
pub outgoing_paid_message_star_count: i64,
pub gift_settings: GiftSettings,
pub bot_verification: Option<BotVerification>,
pub main_profile_tab: Option<ProfileTab>,
pub first_profile_audio: Option<Audio>,
pub rating: Option<UserRating>,
pub pending_rating: Option<UserRating>,
pub pending_rating_date: i32,
pub note: Option<FormattedText>,
pub business_info: Option<BusinessInfo>,
pub bot_info: Option<BotInfo>,
}Expand description
Contains full information about a user
Fields
personal_photo: Option<ChatPhoto>User profile photo set by the current user for the contact; may be null. If null and user.profile_photo is null, then the photo is empty; otherwise, it is unknown. If non-null, then it is the same photo as in user.profile_photo and chat.photo. This photo isn’t returned in the list of user photos
photo: Option<ChatPhoto>User profile photo; may be null. If null and user.profile_photo is null, then the photo is empty; otherwise, it is unknown. If non-null and personal_photo is null, then it is the same photo as in user.profile_photo and chat.photo
public_photo: Option<ChatPhoto>User profile photo visible if the main photo is hidden by privacy settings; may be null. If null and user.profile_photo is null, then the photo is empty; otherwise, it is unknown. If non-null and both photo and personal_photo are null, then it is the same photo as in user.profile_photo and chat.photo. This photo isn’t returned in the list of user photos
block_list: Option<BlockList>Block list to which the user is added; may be null if none
can_be_called: boolTrue, if the user can be called
supports_video_calls: boolTrue, if a video call can be created with the user
has_private_calls: boolTrue, if the user can’t be called due to their privacy settings
has_private_forwards: boolTrue, if the user can’t be linked in forwarded messages due to their privacy settings
has_restricted_voice_and_video_note_messages: boolTrue, if voice and video notes can’t be sent or forwarded to the user
has_posted_to_profile_stories: boolTrue, if the user has posted to profile stories
has_sponsored_messages_enabled: boolTrue, if the user always enabled sponsored messages; known only for the current user
need_phone_number_privacy_exception: boolTrue, if the current user needs to explicitly allow to share their phone number with the user when the method addContact is used
set_chat_background: boolTrue, if the user set chat background for both chat users and it wasn’t reverted yet
bio: Option<FormattedText>A short user bio; may be null for bots
birthdate: Option<Birthdate>Birthdate of the user; may be null if unknown
personal_chat_id: i64Identifier of the personal chat of the user; 0 if none
gift_count: i32Number of saved to profile gifts for other users or the total number of received gifts for the current user
group_in_common_count: i32Number of group chats where both the other user and the current user are a member; 0 for the current user
incoming_paid_message_star_count: i64Number of Telegram Stars that must be paid by the user for each sent message to the current user
outgoing_paid_message_star_count: i64Number of Telegram Stars that must be paid by the current user for each sent message to the user
gift_settings: GiftSettingsSettings for gift receiving for the user
bot_verification: Option<BotVerification>Information about verification status of the user provided by a bot; may be null if none or unknown
main_profile_tab: Option<ProfileTab>The main tab chosen by the user; may be null if not chosen manually
first_profile_audio: Option<Audio>The first audio file added to the user’s profile; may be null if none
rating: Option<UserRating>The current rating of the user; may be null if none
pending_rating: Option<UserRating>The rating of the user after the next change; may be null if the user isn’t the current user or there are no pending rating changes
pending_rating_date: i32Unix timestamp when rating of the user will change to pending_rating; 0 if the user isn’t the current user or there are no pending rating changes
note: Option<FormattedText>Note added to the user’s contact; may be null if none
business_info: Option<BusinessInfo>Information about business settings for Telegram Business accounts; may be null if none
bot_info: Option<BotInfo>For bots, information about the bot; may be null if the user isn’t a bot