pub struct UserPrivacySettingRuleAllowChatMembers {
pub chat_ids: Vec<i64>,
}Expand description
A rule to allow all members of certain specified basic groups and supergroups to doing something
Fields
chat_ids: Vec<i64>The chat identifiers, total number of chats in all rules must not exceed 20