pub struct UserPrivacySettingRuleAllowUsers {
pub user_ids: Vec<i64>,
}Expand description
A rule to allow certain specified users to do something
Fields
user_ids: Vec<i64>The user identifiers, total number of users in all rules must not exceed 1000