pub struct UserTypeBot {
pub can_be_edited: bool,
pub can_join_groups: bool,
pub can_read_all_group_messages: bool,
pub has_main_web_app: bool,
pub has_topics: bool,
pub allows_users_to_create_topics: bool,
pub is_inline: bool,
pub inline_query_placeholder: String,
pub need_location: bool,
pub can_connect_to_business: bool,
pub can_be_added_to_attachment_menu: bool,
pub active_user_count: i32,
}Expand description
A bot (see https:core.telegram.org/bots)
Fields
can_be_edited: boolTrue, if the bot is owned by the current user and can be edited using the methods toggleBotUsernameIsActive, reorderBotActiveUsernames, setBotProfilePhoto, setBotName, setBotInfoDescription, and setBotInfoShortDescription
can_join_groups: boolTrue, if the bot can be invited to basic group and supergroup chats
can_read_all_group_messages: boolTrue, if the bot can read all messages in basic group or supergroup chats and not just those addressed to the bot. In private and channel chats a bot can always read all messages
has_main_web_app: boolTrue, if the bot has the main Web App
has_topics: boolTrue, if the bot has topics
allows_users_to_create_topics: boolTrue, if users can create and delete topics in the chat with the bot
is_inline: boolTrue, if the bot supports inline queries
inline_query_placeholder: StringPlaceholder for inline queries (displayed on the application input field)
need_location: boolTrue, if the location of the user is expected to be sent with every inline query to this bot
can_connect_to_business: boolTrue, if the bot supports connection to Telegram Business accounts
True, if the bot can be added to attachment or side menu
active_user_count: i32The number of recently active users of the bot