pub struct Usernames {
pub active_usernames: Vec<String>,
pub disabled_usernames: Vec<String>,
pub editable_username: String,
pub collectible_usernames: Vec<String>,
}Expand description
Describes usernames assigned to a user, a supergroup, or a channel
Fields
active_usernames: Vec<String>List of active usernames; the first one must be shown as the primary username. The order of active usernames can be changed with reorderActiveUsernames, reorderBotActiveUsernames or reorderSupergroupActiveUsernames
disabled_usernames: Vec<String>List of currently disabled usernames; the username can be activated with toggleUsernameIsActive, toggleBotUsernameIsActive, or toggleSupergroupUsernameIsActive
editable_username: StringActive or disabled username, which may be changed with setUsername or setSupergroupUsername
collectible_usernames: Vec<String>Collectible usernames that were purchased at https:fragment.com and can be passed to getCollectibleItemInfo for more details