pub struct VideoMessageAdvertisement {
pub unique_id: i64,
pub text: String,
pub min_display_duration: i32,
pub max_display_duration: i32,
pub can_be_reported: bool,
pub sponsor: AdvertisementSponsor,
pub title: String,
pub additional_info: String,
}Expand description
Describes an advertisent to be shown while a video from a message is watched
Fields
unique_id: i64Unique identifier of this result
text: StringText of the advertisement
min_display_duration: i32The minimum amount of time the advertisement must be displayed before it can be hidden by the user, in seconds
max_display_duration: i32The maximum amount of time the advertisement must be displayed before it must be automatically hidden, in seconds
can_be_reported: boolTrue, if the advertisement can be reported to Telegram moderators through reportVideoMessageAdvertisement
sponsor: AdvertisementSponsorInformation about the sponsor of the advertisement
title: StringTitle of the sponsored message
additional_info: StringIf non-empty, additional information about the sponsored message to be shown along with the message