pub struct VideoMessageAdvertisements {
pub advertisements: Vec<VideoMessageAdvertisement>,
pub start_delay: i32,
pub between_delay: i32,
}Expand description
Contains a list of advertisements to be shown while a video from a message is watched
Fields
advertisements: Vec<VideoMessageAdvertisement>List of advertisements
start_delay: i32Delay before the first advertisement is shown, in seconds
between_delay: i32Delay between consecutive advertisements, in seconds