pub async fn connect_affiliate_program(
affiliate: AffiliateType,
bot_user_id: i64,
client_id: i32,
) -> Result<ConnectedAffiliateProgram, Error>Expand description
Connects an affiliate program to the given affiliate. Returns information about the connected affiliate program
Arguments
affiliate- The affiliate to which the affiliate program will be connectedbot_user_id- Identifier of the bot, which affiliate program is connectedclient_id- The client id to send the request to