pub async fn encrypt_group_call_data(
group_call_id: i32,
data_channel: GroupCallDataChannel,
data: String,
unencrypted_prefix_size: i32,
client_id: i32,
) -> Result<Data, Error>Expand description
Encrypts group call data before sending them over network using tgcalls
Arguments
group_call_id- Group call identifier. The call must not be a video chatdata_channel- Data channel for which data is encrypteddata- Data to encryptunencrypted_prefix_size- Size of data prefix that must be kept unencryptedclient_id- The client id to send the request to