pub async fn save_prepared_inline_message(
user_id: i64,
result: InputInlineQueryResult,
chat_types: TargetChatTypes,
client_id: i32,
) -> Result<PreparedInlineMessageId, Error>Expand description
Saves an inline message to be sent by the given user; for bots only
Arguments
user_id- Identifier of the userresult- The description of the messagechat_types- Types of the chats to which the message can be sentclient_id- The client id to send the request to