pub async fn set_application_verification_token(
verification_id: i64,
token: String,
client_id: i32,
) -> Result<(), Error>Expand description
Informs TDLib that application or reCAPTCHA verification has been completed. Can be called before authorization
Arguments
verification_id- Unique identifier for the verification process as received from updateApplicationVerificationRequired or updateApplicationRecaptchaVerificationRequiredtoken- Play Integrity API token for the Android application, or secret from push notification for the iOS application for application verification, or reCAPTCHA token for reCAPTCHA verifications; pass an empty string to abort verification and receive the error “VERIFICATION_FAILED” for the requestclient_id- The client id to send the request to