pub async fn summarize_message(
chat_id: i64,
message_id: i64,
translate_to_language_code: String,
client_id: i32,
) -> Result<FormattedText, Error>Expand description
Summarizes content of the message with non-empty summary_language_code
Arguments
chat_id- Identifier of the chat to which the message belongsmessage_id- Identifier of the messagetranslate_to_language_code- Pass a language code to which the summary will be translated; may be empty if translation isn’t needed. See translateText.to_language_code for the list of supported valuesclient_id- The client id to send the request to