pub struct AuctionStateActive {Show 13 fields
pub start_date: i32,
pub end_date: i32,
pub min_bid: i64,
pub bid_levels: Vec<AuctionBid>,
pub top_bidder_user_ids: Vec<i64>,
pub rounds: Vec<AuctionRound>,
pub current_round_end_date: i32,
pub current_round_number: i32,
pub total_round_count: i32,
pub distributed_item_count: i32,
pub left_item_count: i32,
pub acquired_item_count: i32,
pub user_bid: Option<UserAuctionBid>,
}Expand description
Contains information about an ongoing or scheduled auction
Fields
start_date: i32Point in time (Unix timestamp) when the auction started or will start
end_date: i32Point in time (Unix timestamp) when the auction will be ended
min_bid: i64The minimum possible bid in the auction in Telegram Stars
bid_levels: Vec<AuctionBid>A sparse list of bids that were made in the auction
top_bidder_user_ids: Vec<i64>User identifiers of at most 3 users with the biggest bids
rounds: Vec<AuctionRound>Rounds of the auction in which their duration or extension rules are changed
current_round_end_date: i32Point in time (Unix timestamp) when the current round will end
current_round_number: i321-based number of the current round
total_round_count: i32The total number of rounds
distributed_item_count: i32The number of items that were purchased on the auction by all users
left_item_count: i32The number of items that have to be distributed on the auction
acquired_item_count: i32The number of items that were purchased by the current user on the auction
user_bid: Option<UserAuctionBid>Bid of the current user in the auction; may be null if none