pub struct BotVerification {
pub bot_user_id: i64,
pub icon_custom_emoji_id: i64,
pub custom_description: FormattedText,
}Expand description
Describes verification status provided by a bot
Fields
bot_user_id: i64Identifier of the bot that provided the verification
icon_custom_emoji_id: i64Identifier of the custom emoji that is used as the verification sign
custom_description: FormattedTextCustom description of verification reason set by the bot. Can contain only Mention, Hashtag, Cashtag, PhoneNumber, BankCardNumber, Url, and EmailAddress entities