pub struct InputMessageVideo {Show 13 fields
pub video: InputFile,
pub thumbnail: Option<InputThumbnail>,
pub cover: Option<InputFile>,
pub start_timestamp: i32,
pub added_sticker_file_ids: Vec<i32>,
pub duration: i32,
pub width: i32,
pub height: i32,
pub supports_streaming: bool,
pub caption: Option<FormattedText>,
pub show_caption_above_media: bool,
pub self_destruct_type: Option<MessageSelfDestructType>,
pub has_spoiler: bool,
}Expand description
A video message
Fields
video: InputFileVideo to be sent. The video is expected to be re-encoded to MPEG4 format with H.264 codec by the sender
thumbnail: Option<InputThumbnail>Video thumbnail; pass null to skip thumbnail uploading
cover: Option<InputFile>Cover of the video; pass null to skip cover uploading; not supported in secret chats and for self-destructing messages
start_timestamp: i32Timestamp from which the video playing must start, in seconds
added_sticker_file_ids: Vec<i32>File identifiers of the stickers added to the video, if applicable
duration: i32Duration of the video, in seconds
width: i32Video width
height: i32Video height
supports_streaming: boolTrue, if the video is expected to be streamed
caption: Option<FormattedText>Video caption; pass null to use an empty caption; 0-getOption(“message_caption_length_max”) characters
show_caption_above_media: boolTrue, if the caption must be shown above the video; otherwise, the caption must be shown below the video; not supported in secret chats
self_destruct_type: Option<MessageSelfDestructType>Video self-destruct type; pass null if none; private chats only
has_spoiler: boolTrue, if the video preview must be covered by a spoiler animation; not supported in secret chats