pub struct InternalLinkTypeMainWebApp {
pub bot_username: String,
pub start_parameter: String,
pub mode: WebAppOpenMode,
}Expand description
The link is a link to the main Web App of a bot. Call searchPublicChat with the given bot username, check that the user is a bot and has the main Web App. If the bot can be added to attachment menu, then use getAttachmentMenuBot to receive information about the bot, then if the bot isn’t added to side menu, show a disclaimer about Mini Apps being third-party applications, ask the user to accept their Terms of service and confirm adding the bot to side and attachment menu, then if the user accepts the terms and confirms adding, use toggleBotIsAddedToAttachmentMenu to add the bot. Then, use getMainWebApp with the given start parameter and mode and open the returned URL as a Web App
Fields
bot_username: StringUsername of the bot
start_parameter: StringStart parameter to be passed to getMainWebApp
mode: WebAppOpenModeThe mode to be passed to getMainWebApp