pub struct MessageProperties {Show 35 fields
pub can_add_offer: bool,
pub can_add_tasks: bool,
pub can_be_approved: bool,
pub can_be_copied: bool,
pub can_be_copied_to_secret_chat: bool,
pub can_be_declined: bool,
pub can_be_deleted_only_for_self: bool,
pub can_be_deleted_for_all_users: bool,
pub can_be_edited: bool,
pub can_be_forwarded: bool,
pub can_be_paid: bool,
pub can_be_pinned: bool,
pub can_be_replied: bool,
pub can_be_replied_in_another_chat: bool,
pub can_be_saved: bool,
pub can_be_shared_in_story: bool,
pub can_edit_media: bool,
pub can_edit_scheduling_state: bool,
pub can_edit_suggested_post_info: bool,
pub can_get_author: bool,
pub can_get_embedding_code: bool,
pub can_get_link: bool,
pub can_get_media_timestamp_links: bool,
pub can_get_message_thread: bool,
pub can_get_read_date: bool,
pub can_get_statistics: bool,
pub can_get_video_advertisements: bool,
pub can_get_viewers: bool,
pub can_mark_tasks_as_done: bool,
pub can_recognize_speech: bool,
pub can_report_chat: bool,
pub can_report_reactions: bool,
pub can_report_supergroup_spam: bool,
pub can_set_fact_check: bool,
pub need_show_statistics: bool,
}Expand description
Contains properties of a message and describes actions that can be done with the message right now
Fields
can_add_offer: boolTrue, if an offer can be added to the message using addOffer
can_add_tasks: boolTrue, if tasks can be added to the message’s checklist using addChecklistTasks if the current user has Telegram Premium subscription
can_be_approved: boolTrue, if the message is a suggested post that can be approved by the user using approveSuggestedPost
can_be_copied: boolTrue, if content of the message can be copied using inputMessageForwarded or forwardMessages with copy options
can_be_copied_to_secret_chat: boolTrue, if content of the message can be copied to a secret chat using inputMessageForwarded or forwardMessages with copy options
can_be_declined: boolTrue, if the message is a suggested post that can be declined by the user using declineSuggestedPost
can_be_deleted_only_for_self: boolTrue, if the message can be deleted only for the current user while other users will continue to see it using the method deleteMessages with revoke == false
can_be_deleted_for_all_users: boolTrue, if the message can be deleted for all users using the method deleteMessages with revoke == true
can_be_edited: boolTrue, if the message can be edited using the methods editMessageText, editMessageCaption, or editMessageReplyMarkup. For live location, poll, and checklist messages this fields shows whether editMessageLiveLocation, stopPoll, or editMessageChecklist respectively can be used with this message
can_be_forwarded: boolTrue, if the message can be forwarded using inputMessageForwarded or forwardMessages without copy options
can_be_paid: boolTrue, if the message can be paid using inputInvoiceMessage
can_be_pinned: boolTrue, if the message can be pinned or unpinned in the chat using pinChatMessage or unpinChatMessage
can_be_replied: boolTrue, if the message can be replied in the same chat and forum topic using inputMessageReplyToMessage
can_be_replied_in_another_chat: boolTrue, if the message can be replied in another chat or forum topic using inputMessageReplyToExternalMessage
can_be_saved: boolTrue, if content of the message can be saved locally
True, if the message can be shared in a story using inputStoryAreaTypeMessage
can_edit_media: boolTrue, if the message can be edited using the method editMessageMedia
can_edit_scheduling_state: boolTrue, if scheduling state of the message can be edited
can_edit_suggested_post_info: boolTrue, if another price or post send time can be suggested using addOffer
True, if author of the message sent on behalf of a chat can be received through getMessageAuthor
can_get_embedding_code: boolTrue, if code for message embedding can be received using getMessageEmbeddingCode
can_get_link: boolTrue, if a link can be generated for the message using getMessageLink
can_get_media_timestamp_links: boolTrue, if media timestamp links can be generated for media timestamp entities in the message text, caption or link preview description using getMessageLink
can_get_message_thread: boolTrue, if information about the message thread is available through getMessageThread and getMessageThreadHistory
can_get_read_date: boolTrue, if read date of the message can be received through getMessageReadDate
can_get_statistics: boolTrue, if message statistics are available through getMessageStatistics and message forwards can be received using getMessagePublicForwards
can_get_video_advertisements: boolTrue, if advertisements for video of the message can be received though getVideoMessageAdvertisements
can_get_viewers: boolTrue, if chat members already viewed the message can be received through getMessageViewers
can_mark_tasks_as_done: boolTrue, if tasks can be marked as done or not done in the message’s checklist using markChecklistTasksAsDone if the current user has Telegram Premium subscription
can_recognize_speech: boolTrue, if speech can be recognized for the message through recognizeSpeech
can_report_chat: boolTrue, if the message can be reported using reportChat
can_report_reactions: boolTrue, if reactions on the message can be reported through reportMessageReactions
can_report_supergroup_spam: boolTrue, if the message can be reported using reportSupergroupSpam
can_set_fact_check: boolTrue, if fact check for the message can be changed through setMessageFactCheck
need_show_statistics: boolTrue, if message statistics must be available from context menu of the message