pub struct UpdateFileGenerationStart {
pub generation_id: i64,
pub original_path: String,
pub destination_path: String,
pub conversion: String,
}Expand description
The file generation process needs to be started by the application. Use setFileGenerationProgress and finishFileGeneration to generate the file
Fields
generation_id: i64Unique identifier for the generation process
original_path: StringThe original path specified by the application in inputFileGenerated
destination_path: StringThe path to a file that must be created and where the new file must be generated by the application. If the application has no access to the path, it can use writeGeneratedFilePart to generate the file
conversion: StringIf the conversion is “#url#” than original_path contains an HTTP/HTTPS URL of a file that must be downloaded by the application. Otherwise, this is the conversion specified by the application in inputFileGenerated