pub struct UpdateGroupCallParticipants {
pub group_call_id: i32,
pub participant_user_ids: Vec<i64>,
}Expand description
The list of group call participants that can send and receive encrypted call data has changed; for group calls not bound to a chat only
Fields
group_call_id: i32Identifier of the group call
participant_user_ids: Vec<i64>New list of group call participant user identifiers. The identifiers may be invalid or the corresponding users may be unknown. The participants must be shown in the list of group call participants even if there is no information about them